%% avoids spurious error message in overleaf:
\PassOptionsToPackage{pdfpagelabels=false}{hyperref} 
%%%%

\def\currversion{Oct 5, 2023}
%\def\currversion{June 8, 2023}
%\def\currversion{April 17, 2023}

\typeout{^^J^^J^^J
Princeton University Press Book Class^^J
Current Version: \currversion^^J^^J
^^J^^J}


  %****************************************************************%
  %*                                                              *%
  %*  Princeton University Press Book Style                       *%
  %*                                                              *%
  %*  by Amy Hendrickson, TeXnology Inc.                          *%
  %*                                                              *%
  %*  amyh@texnology.com                                          *%
  %*  617 738-8029                                                *%
  %*  http://www.texnology.com                                    *%
  %*                                                              *%
  %****************************************************************%


%% SEARCH BELOW FOR THE NUMBER TO FIND PARTICULAR MACRO GROUP

    %% Macro Contents:
    %% 1) Making Documentclass Options/Conditionals
    %%
    %% 2) Execute and Process Options
    %%
    %% 3) Define font sizes, dimensions, similar to bk10.clo
    %%
    %% 3B) Bookmarks
    %%
    %% 4) Utilities, Macros to be used in other macros later
    %%
    %% 5) Setting default dimensions, global parameters
    %%
    %% 6) Bringing in Selected Usepackages     
    %%
    %% 7) Font Settings, Set Main Font, vertical space between lines
    %%
    %% 8) Frontmatter: Titlepages, Introduction, Brief TOC, TOC,
    %%        `List of ??' environments, Bookmarks
    %%
    %% 9) Endmatter: Appendices, Endnotes, Bibliography, Indices 
    %%
    %% 10) Part, Chapter Commands 
    %%
    %% 11) Section Commands 
    %%
    %% 12) Running Heads, Crop Marks
    %%
    %% 13) Listing 
    %%
    %% 14) Figure and Table Captions 
    %%
    %% 15) Colors 
    %%
    %% 16) Shaded Code, (verbatim with shading behind, commands to turn off shading), Framed
    %%
    %% 17) Algorithms
    %%
    %% 18) Notations
    %%
    %% 19) Exercises and Answers
    %%
    %% 20) Theorem Environments
    %%
    %% 21) Hyperref, hypertext linking
    %%
    %% 22) Settings for start of document

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%      1) Making Documentclass Options/Conditionals 

%% 6x9 is default
\newif\ifsixbynine
\newif\ifsevenbyten
\DeclareOption{6x9}{\global\sixbyninetrue\global\sevenbytenfalse}

%% default is sixbynine
\sixbyninetrue 
\global\sevenbytenfalse

\DeclareOption{7x10}{\global\sevenbytentrue\global\sixbyninefalse}

\newif\ifxdraft
\DeclareOption{draft}{\global\xdrafttrue}

\newif\ifAnnalsOfMath

\DeclareOption{AnnalsOfMath}{\global\AnnalsOfMathtrue
\global\stixfontsfalse}
%% Above, makes Times Fonts default for AOM Books, 
%% Below, STIXfonts are default for all others.
\newif\ifstixfonts
\global\stixfontstrue %% default font set

%%%%%%%%%%%%%%%%
%% Font Set Choice

%% STIX fonts are default, unless TimesFonts is 
%% used as a documentclass option



%% TimesFonts are default for AOM Books
\DeclareOption{TimesFonts}{\global\stixfontsfalse}
\DeclareOption{STIXFonts}{\global\stixfontstrue}

%%%%%%%%%%%%%%%%
%% No cropmarks (cropmarks are default)
\newif\ifnocropmarks
\DeclareOption{nocropmarks}{\global\nocropmarkstrue
\global\let\CROP@@@marks\relax
}

%%%%%%%%%%%%%%%%
%Book Endnotes
\newcounter{endnote}
\newif\ifEndnote
\DeclareOption{BookEndNotes}{\global\Endnotetrue\global\ChapEndnotefalse}


%%%%%%%%%%%%%%%%
% Chapter Endnotes
\newif\ifChapEndnote
\DeclareOption{ChapEndNotes}{\global\ChapEndnotetrue\global\Endnotefalse}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Choose ebook or print. The difference is
% whether or not to have binding offset, not
% necessary in ebook.

\newif\ifebook
\global\ebooktrue

\DeclareOption{printbook}
   {\global\ebookfalse}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Multiple Indices

\newif\ifmultipleindices
\DeclareOption{MultIndices}{\global\multipleindicestrue}%

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Draft version, xDraft
%% Don't use \draft for option because graphicx will not print illustrations
%% if \draft is true. May not need this.
\newif\ifxdraft

\setlength{\overfullrule}{\z@}
\DeclareOption{final}{\setlength{\overfullrule}{\z@}
                      \xdraftfalse}

\DeclareOption{PUP-draft}{\setlength\overfullrule{5pt}%
   \sloppy                   \global\xdrafttrue}

\DeclareOption{Pup-draft}{\setlength\overfullrule{5pt}%
   \sloppy                   \global\xdrafttrue}

\DeclareOption{pup-draft}{\setlength\overfullrule{5pt}%
   \sloppy                   \global\xdrafttrue}



%%%% From Pup6x9 ==>>
\newif\if@openright
\newif\if@openleft
\newif\ifopenany
\DeclareOption{openright}{\@openrighttrue}
\DeclareOption{openany}{\@openrightfalse}
\DeclareOption{openleft}{\@openlefttrue}
\newcommand{\openright}{\@openrighttrue\@openleftfalse%
  \gdef\clearforchapter{\cleartorecto}}
\newcommand{\openany}{\@openrightfalse\@openleftfalse%
  \gdef\clearforchapter{\clearpage}}
\newcommand{\openleft}{\@openlefttrue
  \gdef\clearforchapter{\cleartoverso}}

\DeclareOption{leqno}{\input{leqno.clo}}
\DeclareOption{fleqn}{\input{fleqn.clo}}
\DeclareOption{openbib}{%
  \AtEndOfClass{%
    \renewcommand\@openbib@code{%
      \advance\leftmargin\bibindent
      \itemindent -\bibindent
      \listparindent \itemindent
      \parsep \z@
     }%
    \renewcommand\newblock{\par}}%
}

\DeclareOption{twoside}{\@twosidetrue  \@mparswitchtrue}
\DeclareOption{oneside}{\@twosidefalse \@mparswitchfalse}

%%% End Option Declarations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\normalsize{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2) Execute and Process Options

\ExecuteOptions{final,letterpaper,onecolumn,openany,twoside}
\ProcessOptions

\ifAnnalsOfMath
\global\stixfontsfalse\fi

%% six by nine is default, actually 6.125in x 9.25in
\ifsevenbyten\else\sixbyninetrue\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% If these are brought in later they cause errors.
%% Needed for AMS commands, and fontspec lets us use
%% any .otf or .ttf font file with no need for other
%% supporting files. Must use xelatex to process the .tex
%% file.
\usepackage{amsmath}
\usepackage{amsthm}
\theoremstyle{plain} %% was definition; changed Oct 5, 2022
\usepackage{fontspec,unicode-math}
\defaultfontfeatures{Ligatures=TeX,
Path=./fonts/ , 
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3) Define font sizes, dimensions, variation on PUP10.clo

\renewcommand{\normalsize}{%
   \@setfontsize\normalsize {10.5}{\ifxdraft 25pt\else 
12.5pt\fi}
   \abovedisplayskip 10\p@ %\@plus2\p@ \@minus5\p@
   \abovedisplayshortskip \z@ %\@plus3\p@
   \belowdisplayshortskip 6\p@ %\@plus3\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}
\normalsize
\newcommand{\small}{%
   \@setfontsize\small\@ixpt{\ifxdraft 24pt\else 11pt\fi}%
   \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus2\p@
   \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 4\p@ \@plus2\p@ \@minus2\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep
%%               \itemindent\z@
              }%
   \belowdisplayskip \abovedisplayskip
}

\newcommand{\bigsmall}{%
   \@setfontsize\bigsmall{10}{\ifxdraft 24pt \else 12pt\fi}%
   \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus2\p@
   \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 4\p@ \@plus2\p@ \@minus2\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep
%%               \itemindent\z@
              }%
   \belowdisplayskip \abovedisplayskip
}

\newcommand{\footnotesize}{%
   \@setfontsize\footnotesize\@viiipt{\ifxdraft 24pt \else 9.5pt\fi}%
   \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus\p@
   \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 3\p@ \@plus\p@ \@minus\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep
%%               \itemindent\z@
              }%
   \belowdisplayskip \abovedisplayskip
}
\newcommand{\miniscule}{\@setfontsize\miniscule\@vpt{6}}
\newcommand{\tiny}{\@setfontsize\tiny\@vipt{7}}
\newcommand{\scriptsize}{\@setfontsize\scriptsize\@viipt{8}}
\newcommand{\large}{\@setfontsize\large\@xipt{\ifxdraft24pt \else
13.6pt\fi}}
\newcommand{\Large}{\@setfontsize\Large\@xiipt{\ifxdraft24pt \else
14.5pt\fi}}
\newcommand{\LARGE}{\@setfontsize\LARGE\@xivpt{\ifxdraft24pt \else
18pt\fi}}
\newcommand{\huge}{\@setfontsize\huge\@xviipt{22}}
\newcommand{\Huge}{\@setfontsize\Huge\@xxpt{25}}
\newcommand{\HUGE}{\@setfontsize\HUGE\@xxvpt{30}}
\if@twocolumn
  \setlength\parindent{1em}
\else
  \setlength\parindent{15\p@}
\fi
\setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}
\setlength\medskipamount{6\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}
\setlength\headheight{12\p@}
\setlength\headsep{.25in}
\setlength\topskip{10\p@}
\setlength\footskip{.35in}
\setlength\maxdepth{.5\topskip}
\setlength\@maxdepth\maxdepth
\setlength\footnotesep{6.65\p@}
\setlength{\skip\footins}{9\p@ \@plus 4\p@ \@minus 2\p@}
\setlength\floatsep    {12\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\textfloatsep{20\p@ \@plus 2\p@ \@minus 4\p@}
\setlength\intextsep   {12\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\dblfloatsep    {12\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\dbltextfloatsep{20\p@ \@plus 2\p@ \@minus 4\p@}
\setlength\@fptop{0\p@ \@plus 1fil}
\setlength\@fpsep{8\p@ \@plus 2fil}
\setlength\@fpbot{0\p@ \@plus 1fil}
\setlength\@dblfptop{0\p@ \@plus 1fil}
\setlength\@dblfpsep{8\p@ \@plus 2fil}
\setlength\@dblfpbot{0\p@ \@plus 1fil}
%\setlength\lxvchars{300\p@} % standard 345pt
%\setlength\xlvchars{204\p@} %
\if@twocolumn
  \setlength\marginparsep{10\p@}
\else
  \setlength\marginparsep{7\p@}
\fi
\setlength{\marginparpush}{5\p@}

%%%% <<== End variation on pup10.clo %%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 3b) Bookmarks
\usepackage[open,
openlevel=2,
atend,
numbered
]{bookmark}

%% for adding bookmark separately from addtocontentsline
\gdef\plainaddcontentsline#1#2#3{\bgroup
\phantomsection
\hypersetup{hypertexnames=true} % must be true for index to work 
\addtocontents{#1}{\protect\contentsline{#2}{#3}{\thepage}{\@currentHref}}
\egroup
}

%% Need this excerpt from output format to access page numbers that
%% continue from first to last page, roman or arabic:
\newcount\acropage
\global\acropage=1

\let\saveoutputpage\@outputpage

\def\@outputpage{\saveoutputpage\global\advance\acropage by 1\relax}


\bookmarksetup{startatroot}%
%%%% <<== End Bookmarks %%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3) Utilities

\newlength{\onelineskip}

\newif\if@restonecol

%% probably don't need this
\newif\ifheadnameref
  \headnamereffalse

%% needthis?
\def\cleartorecto{\clearpage\if@twoside \ifodd\c@page\else
  \hbox{}\thispagestyle{empty}%
  \newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi}

%% needthis?
\def\cleartoverso{\clearpage\if@twoside
  \ifodd\c@page\hbox{}\thispagestyle{empty}%
  \newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi}

\newcommand{\today}{\ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space\number\day, \number\year}

%% Conditionals that we can set and use later
\newif\if@openright
\newif\ifmainmatter 
\newif\ifendmatter
\newif\if@restonecol
\newif\if@titlepage

%% for breaking lines in chapter head
\def\breakline{\vskip-\parskip\noindent\relax}

\if@openleft
  \openleft
\else
  \if@openright
    \openright
  \else
    \openany
  \fi
\fi

\def\indexspace{\vskip1sp}

\newenvironment{quotation}
               {\list{}{\listparindent 1.5em%
                        \itemindent    \listparindent
                        \rightmargin   \leftmargin
                        \parsep        \z@ \@plus\p@}%
\def\source##1{\vskip-4pt\vskip1sp\item[]\hfill ##1}       
         \item[]}%
               {\endlist}
\newenvironment{quote}
               {\list{}{\rightmargin\leftmargin}%
\def\source##1{\vskip-4pt\vskip1sp\item[]\hfill ##1}       
         \item[]}%
               {\endlist}


\newcommand{\symbollabel}[1]{{#1 \hfill}}

%\newcommand{\@nameedef}[1]{
 % \expandafter\protected@edef\csname #1\endcsname}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% \frontmatter, \mainmatter, \endmatter
\newif\iffrontmatter
\def\frontmatter{\global\frontmattertrue
\pagenumbering{roman}}

\newif\ifmainmatter
\def\mainmatter{\global\mainmattertrue
\pagenumbering{arabic}}

\newcommand{\backmatter}{%
\global\mainmatterfalse}

%% 
\newcommand{\cleartooddpage}[1][\@empty]{%
  \clearpage%
  \ifodd\c@page\else\hbox{}#1\clearpage\fi}

\def\thepage{\the\c@page}

\long\def\ifdefined#1{\ifx\expandafter\csname#1\endcsname\relax
\let\go\relax%
\else
\long\def\go##1{#1}\fi}


\def\startonoddpage{\clearpage
\ifodd\c@page\else
\thispagestyle{empty}
\null\newpage\fi
}

\def\cleardoublepage{\clearpage\if@twoside \ifodd\c@page\else
    \hbox{}\newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi}

%%%%%%%%
%%% Frontmatter, Mainmatter, Endmatter

\def\mainmatter{\pagenumbering{arabic}
\global\mainmattertrue}

\pagenumbering{roman} %% default
\def\frontmatter{\cleardoublepage \mainmatterfalse \pagenumbering
{roman}}

\def\mainmatter{\cleardoublepage\global\let\currchaptitle\relax \mainmattertrue \pagenumbering
{arabic}}

\def\backmatter{\if@openright \cleardoublepage \else \clearpage \fi
\mainmatterfalse} 
%%%%% <<== end frontmatter,mainmatter,endmatter %%%%

\renewcommand\theequation
  {\ifnum \c@chapter>\z@ \thechapter.\fi% 
\@arabic\c@equation}

\def\sectionbreak{\vspace *{1\baselineskip }\@afterheading
\@afterindentfalse}

\let\savedblbackslash\\
\def\nocentering{%
  \let\\\savedblbackslash
  \rightskip=0pt
\leftskip=0pt
  \parindent15pt\parfillskip0pt plus 1fil}

%%%% <<== End Utilities %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%
% 4) Setting Default Dimensions, and Global parameters


\topmargin12pt
\headheight 18pt
\headsep 30pt
\topskip  10pt
\footskip 15pt 

\columnsep 10pt
\columnseprule 0pt

\footnotesep 6.65pt
\skip\footins 10pt plus .1pt minus .1pt

\floatsep 12pt %plus 2pt minus 2pt
\textfloatsep 10pt %plus 2pt minus 4pt
\intextsep 12pt %plus 2pt minus 2pt

\dblfloatsep 12pt %plus 2pt minus 2pt
\dbltextfloatsep 20pt %plus 2pt minus 4pt

%% float placement, used by output routine
\@fptop 0pt plus 1fil
\@fpsep 8pt plus 2fil
\@fpbot 0pt plus 1fil
\@dblfptop 0pt plus 1fil
\@dblfpsep 8pt plus 2fil
\@dblfpbot 0pt plus 1fil

  %% page makeup, used by output routine and also for
  %% splitting boxes
\maxdepth=4pt   %% 2e default is .5\topskip
\marginparwidth .75in

\if@twocolumn
 \setlength\marginparsep {10\p@}
\else
  \setlength\marginparsep{7\p@}
\fi

\setlength\marginparpush{5\p@}
\setlength\partopsep{0pt}%2\p@ \@plus 1\p@ \@minus 1\p@}

\setcounter{topnumber}{10}
\def\topfraction{.9}
\setcounter{bottomnumber}{10}
\def\bottomfraction{.1}
\setcounter{totalnumber}{10}
\def\textfraction{.2}
\def\floatpagefraction{.5}
\setcounter{dbltopnumber}{2}
\def\dbltopfraction{.7}
\def\dblfloatpagefraction{.5}
%%%

\setlength\arraycolsep{5\p@}
\tabcolsep 6pt
\setlength\arrayrulewidth{.4\p@}

  %% space between two lines in array
\setlength\doublerulesep{2\p@}

  %% space between two lines in tabular
\setlength\tabbingsep{\labelsep}

  %% Minipage
  %% minipage space
\skip\@mpfootins = \skip\footins

  %% Framebox \fbox{} or \framebox{}
  %% space between line in framebox and text within it
\setlength\fboxsep{3\p@}

  %% width of ruled line in framebox
\setlength\fboxrule{.4\p@}

\setlength\arraycolsep{5\p@}
\setlength\tabcolsep{6\p@}
\setlength\arrayrulewidth{.4\p@}
\setlength\doublerulesep{2\p@}
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Setting Existing Dimensions

\setlength\parindent{15\p@}
\setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}
\setlength\medskipamount{6\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}
\setlength\headheight{12\p@}
\setlength\headsep{.25in}
\setlength\topskip{10\p@}
\setlength\footskip{.35in}
\setlength\maxdepth{.5\topskip}
\setlength\@maxdepth\maxdepth
\setlength\footnotesep{6.65\p@}
\setlength{\skip\footins}{9\p@ \@plus 4\p@ \@minus 2\p@}
\setlength\floatsep    {12\p@ %\@plus 2\p@ \@minus 2\p@
}
\setlength\textfloatsep{20\p@ %\@plus 2\p@ \@minus 4\p@
}
\setlength\intextsep   {12\p@ %\@plus 2\p@ \@minus 2\p@
}
\setlength\dblfloatsep    {12\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\dbltextfloatsep{20\p@ \@plus 2\p@ \@minus 4\p@}
\setlength\@fptop{0\p@ \@plus 1fil}
\setlength\@fpsep{8\p@ \@plus 2fil}
\setlength\@fpbot{0\p@ \@plus 1fil}
\setlength\@dblfptop{0\p@ \@plus 1fil}
\setlength\@dblfpsep{8\p@ \@plus 2fil}
\setlength\@dblfpbot{0\p@ \@plus 1fil}
\setlength\marginparsep{7\p@}
\setlength{\marginparpush}{5\p@}


%% Setting Global parameters ==>>

  %% Makes sure that there will not be any widow or club lines,
  %% smaller numbers allow them occassionally, but you probably need
  %% these set to 10000 so that there are never any

\widowpenalty10000
\clubpenalty10000

  %% How many levels deep do you want sections to be numbered-- higher number
  %% means more levels will be numbered. Here was are asking only for
  %% sections to be numbered, not subsections, or subsubsection etc.
\setcounter{secnumdepth}{4}

  %% How many levels of section heads do you want to appear in the
  %% table of contents: here we are asking for only parts, chapters and
  %% sections to appear.
\setcounter{tocdepth}{1}

  %% To make left and right page position differently, and have
  %% running heads be different on even and odd pages
\@twosidetrue  

  %% Marginal notes should be on the left on even numbered pages; on
  %% right on odd numbered pages.
\@mparswitchtrue

  %% Starting with one column text
\@twocolumnfalse

  %% openbib will allow separate lines for parts of bibliography
  %% entries, default is to run different parts of bib entry into a
  %% paragraph form.

\newif\if@openbib
\@openbibfalse

%% Start new chapter on right side:
\@openrighttrue


%%% Declare names %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand*{\abstractname}{Abstract}
\newcommand*{\contentsname}{Contents}
\newcommand*{\listfigurename}{List of Figures}
\newcommand*{\listtablename}{List of Tables}
\newcommand*{\partname}{Part}
\newcommand*{\chaptername}{Chapter}
\newcommand*{\appendixname}{Appendix}
\newcommand*{\appendixtocname}{Appendices}
\newcommand*{\appendixpagename}{Appendices}
\def\bibname{Bibliography}%
\newcommand*{\indexname}{Index}
\newcommand*{\glossaryname}{Glossary}
\newcommand*{\figurename}{Figure}
\newcommand*{\tablename}{Table}
\newcommand*{\figurerefname}{Figure}
\newcommand*{\tablerefname}{Table}
\newcommand*{\refname}{Bibliography}
\newcommand*{\pagename}{page}
\newcommand*{\pagerefname}{page}
\newcommand*{\partrefname}{Part~}
\newcommand*{\chapterrefname}{Chapter~}
\newcommand*{\sectionrefname}{\S}
%%% <<== End names %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Define and Set Counters
\newcounter{part}
\newcounter{chapter}
\newcounter{section}[chapter]
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]
\newcounter{subparagraph}[paragraph]

\renewcommand{\thepart}{\@Roman\c@part}
\renewcommand{\thechapter}{{\@arabic\c@chapter}}
\renewcommand{\thesection}{{{\thechapter.\@arabic\c@section}}}
\renewcommand{\thesubsection}{{{\thesection.\@arabic\c@subsection}}}
\renewcommand{\thesubsubsection}{{{\thesubsection.\@arabic\c@subsubsection}}}
\renewcommand{\theparagraph}{{{\thesubsubsection.\@arabic\c@paragraph}}}
\renewcommand{\thesubparagraph}{{{\theparagraph.\@arabic\c@subparagraph}}}

%% This is changed from Chapter to Appendix with the \appendix command:
\newcommand{\@chapapp}{\chaptername}

\setcounter{part}{0}
\setcounter{chapter}{0}
\setcounter{tocdepth}{1}
\setcounter{secnumdepth}{3}

%%% <== end setting dimensions and global parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 6) Bringing in selected Usepackages

%% Graphics
\usepackage{graphicx}
\usepackage{multicol}
\usepackage{longtable}
\usepackage{url}
  \def\UrlBreaks{\do\/\do-}
  \urlstyle{sf}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 7) Font Settings, Set Main Font, vertical space between lines
%%    Font declarations for particular use, like chapter number, etc.    


\ifstixfonts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% STIX Fonts (newer version of Times) /HelveticaNeue Fonts

%% Math fonts:
\setmathfont{STIX2Math}[
Extension={.otf},
Path=./fonts/ ,
Scale=1]

%% Body Font:
\setmainfont{STIX2Text}[%
%WordSpace={2.5,1.2,0},
WordSpace={1.5,1.2,0},
Extension={.otf},
UprightFont={STIX2Text-Regular},
BoldFont={STIX2Text-Bold},
ItalicFont={STIX2Text-Italic},
BoldItalicFont={STIX2Text-BoldItalic}]

%% half titlepage title
\def\halftitlepagefont{\fontsize{18}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

%% Part page
\def\partnumfont{\fontsize{24}{28}%
\fontspec{HelveticaNeueLTStd-It.otf}}

\def\parttitlefont{
\fontsize{20}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}


%\def\partnamefont{\fontsize{20}{24pt}%
%\fontspec{HelveticaNeueLTStd-Lt.otf}}

%% titlepage title
\def\booktitlefont{\fontsize{20}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\booksubtitlefont{\fontsize{12}{16pt}%
\fontspec{HelveticaNeueLTStd-It.otf}}

\def\bookauthorfont{\fontsize{16}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\princetonfont{\fontsize{8}{16pt}%
\fontspec{HelveticaNeueLTStd-Roman.otf}}

%% Chapter opening

\def\chapnumberfont{\fontsize{16}{28}%
\fontspec{HelveticaNeueLTStd-It.otf}}

%\def\chapnumberfont{\fontsize{14}{12} % was 24
%\fontspec{HelveticaNeueLTStd-LT.otf}}

\def\chaptitlefont{\fontsize{16}{22pt}% was 14
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\chapsubtitlefont{\fontsize{12}{14pt}%
\fontspec{HelveticaNeueLTStd-LtIt.otf}}


\def\chapauthorfont{\fontsize{10}{12pt}%
\sc}


%% caption
\def\captionnamefont{\fontsize{10.5}{12.5}
\bf}

\def\captiontextfont{\fontsize{9}{11}%
\bf}

\def\sectionfont{\fontsize{10.5}{14}%
\bf}

\def\subsectionfont{\fontsize{10}{12}%
\bf}

\def\subsubsectionfont{\fontsize{10}{12}%
\it}

\def\paragraphfont{\fontsize{10}{12}%
\sc}

\let\subparagraphfont\subsubsectionfont

%% running heads
\def\runningheadfont{\fontsize{8}{10}%
\fontspec{HelveticaNeueLTStd-Roman.otf}}

\def\foliofont{\normalsize\rm}

\def\schapterfont{\fontsize{16}{28}%
\fontspec{HelveticaNeueLTStd-It.otf}}

\def\titlepagefont{\fontsize{40}{46}%
\fontspec{HelveticaNeueLTStd-Roman.otf}
\addfontfeature{LetterSpace=12}}

\def\smauthorfont{\fontsize{9}{11}%
\fontspec{\bf}}

\def\boxedtextfont{\fontsize{11}{13}%
\fontspec{HelveticaNeueLTStd-Md.otf}
}
\fi
%% End if STIXfonts/Helvetica Fonts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ifstixfonts\else

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% TimesNewRoman/HelveticaNeue Fonts

\def\partnumfont{\fontsize{24}{28}%
\fontspec{HelveticaNeueLTStd-It.otf}}

\def\parttitlefont{
\fontsize{20}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

%% titlepage title
\def\booktitlefont{\fontsize{20}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\booksubtitlefont{\fontsize{12}{16pt}%
\fontspec{HelveticaNeueLTStd-It.otf}}

\def\bookauthorfont{\fontsize{16}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\princetonfont{\fontsize{8}{16pt}%
\fontspec{HelveticaNeueLTStd-Roman.otf}}

%% Chapter opening

\def\chapnumberfont{\fontsize{16}{28}%
\fontspec{HelveticaNeueLTStd-It.otf}}


\def\chaptitlefont{\fontsize{16}{22pt}% was 14
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\chapsubtitlefont{\fontsize{12}{14pt}%
\fontspec{HelveticaNeueLTStd-LtIt.otf}}

\def\chapauthorfont{\fontsize{10}{12pt}%
\sc}

\def\boxedtextfont{\fontsize{11}{13}%
\fontspec{HelveticaNeueLTStd-Md.otf}}
%% caption
\def\captionnamefont{\fontsize{10}{11}
\fontspec{TimesNewRomanMTStd-Bold.otf}}

\def\captiontextfont{\fontsize{9}{11}%
\fontspec{TimesNewRomanMTStd-Roman.otf}}

\def\sectionfont{\fontsize{10.5}{14}%
\fontspec{TimesNewRomanMTStd-Bold.otf}}

\def\subsectionfont{\fontsize{10}{12}%
\fontspec{TimesNewRomanMTStd-Bold.otf}}%

\def\subsubsectionfont{\fontsize{10}{12}%
\fontspec{TimesNewRomanMTStd-Italic.otf}}%

\def\paragraphfont{\fontsize{10}{12}%
\fontspec{Times-RomanSC.otf}}

\let\subparagraphfont\subsubsectionfont

%% running heads
\def\runningheadfont{\fontsize{8}{10}%
\fontspec{HelveticaNeueLTStd-Roman.otf}}

\def\foliofont{\normalsize\rm}

%% Body Font
\def\Times{\setmainfont[Ligatures=TeX, 
WordSpace=1.3,
BoldFont=TimesNewRomanMTStd-Bold.otf,
ItalicFont=TimesNewRomanMTStd-Italic.otf,
BoldItalicFont=TimesNewRomanMTStd-BoldIt.otf]
{TimesNewRomanMTStd.otf}}

\Times

%% Math fonts, for Stix fonts, and Times New Roman
\setmathfont{STIX2Math}[
Extension={.otf},
Path=./fonts/ ,
Scale=1]

%%%

\def\textsc#1{{\normalsize\fontspec{Times-RomanSC.otf}%
{#1}}}

\def\schapterfont{\fontsize{16}{28}%
\fontspec{HelveticaNeueLTStd-It.otf}}

\def\titlepagefont{\fontsize{40}{46}%
\fontspec{HelveticaNeueLTStd-Roman.otf}
\addfontfeature{LetterSpace=12}}

\def\smauthorfont{\fontsize{9}{11}%
\fontspec{TimesLTStd-Bold.otf}}

%% End Times/Helvetica Fonts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\fi %% end of test of ifstixfonts \else times \fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% half titlepage title
\ifAnnalsOfMath
\def\AOMhalftitlepagefont{\fontsize{20}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}

\def\AOMnumberhalftitlepagefont{%
\fontsize{20}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}
\else
%% half titlepage font
\def\halftitlepagefont{\fontsize{18}{24pt}%
\fontspec{HelveticaNeueLTStd-Lt.otf}}
\fi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\verbatim@font{\fontsize{9.5}{12}%
\ttfamily}

%% for compatibility with older markup:
\@maxdepth\maxdepth
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareRobustCommand{\cal}{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand{\mit}{\@fontswitch{\relax}{\mathnormal}}

%% end fonts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 8) Frontmatter 

%%%%%%%%%%%%%%%%%%%%%%
%% Title Page Commands

%% this can be reduced.
\newcommand{\pretitle}[1]{\def\@bspretitle{#1}}
\newcommand{\posttitle}[1]{\def\@bsposttitle{#1}}
\newcommand{\preauthor}[1]{\def\@bspreauthor{#1}}
\newcommand{\postauthor}[1]{\def\@bspostauthor{#1}}
\newcommand{\predate}[1]{\def\@bspredate{#1}}
\newcommand{\postdate}[1]{\def\@bspostdate{#1}}

  \pretitle{\begin{center}\LARGE}
  \posttitle{\par\end{center}\vskip 0.5em}
  \preauthor{\begin{center}
    \large \lineskip .5em%
    \begin{tabular}[t]{c}}
  \postauthor{\end{tabular}\par\end{center}}
  \predate{\begin{center}\large}
  \postdate{\par\end{center}}

\newcommand{\maketitlehooka}{}
\newcommand{\maketitlehookb}{}
\newcommand{\maketitlehookc}{}
\newcommand{\maketitlehookd}{}

\newcommand{\thanksmarkseries}[1]{%
  \def\@bsmarkseries{\renewcommand{\thefootnote}%
                     {\@nameuse{#1}{footnote}}}}
\newcommand{\symbolthanksmark}{\thanksmarkseries{\fnsymbol}}
\newcommand{\@bscontmark}{\setcounter{footnote}{0}}
\newcommand{\continuousmarks}{\def\@bscontmark{}}
\newcommand{\thanksheadextra}[2]{%
  \def\@bsthanksheadpre{#1}%
  \def\@bsthanksheadpost{#2}}

\DeclareRobustCommand{\thanksmark}[1]{\footnotemark[#1]}
\newcommand{\thanksgap}[1]{\hspace{#1}}
\newcommand{\tamark}{\@thefnmark}

\newlength{\thanksmarkwidth}
\newlength{\thanksmarksep}
\newcommand{\thanksmarkstyle}[1]{\def\thanksscript##1{#1}}
\thanksmarkstyle{\textsuperscript{#1}}
\newcommand{\makethanksmarkhook}{}

\newcommand{\thanksfootmark}{%
  \ifdim\thanksmarkwidth < \z@
    \llap{\hb@xt@ -\thanksmarkwidth{%
          \hss\normalfont\thanksscript{\tamark}}%
          \hspace*{-\thanksmarkwidth}}%
  \else
    \ifdim\thanksmarkwidth = \z@
      {\normalfont\thanksscript{\tamark}}%
    \else
      \hb@xt@\thanksmarkwidth{\hss\normalfont\thanksscript{\tamark}}%
    \fi
  \fi}

\newcommand{\makethanksmark}{%
  \leavevmode%
  \parindent 1em\noindent
  \leftskip\thanksmarksep\relax
  \advance\leftskip\thanksmarkwidth \null\nobreak\hskip-\leftskip\relax
  \makethanksmarkhook\relax
  \thanksfootmark}

\newcommand{\usethanksrule}{\let\footnoterule\thanksrule}
\newcommand{\cancelthanksrule}{\let\footnoterule\@bsfootnoterule}

\thanksmarkseries{fnsymbol}  % symbols
\thanksheadextra{}{}
\setlength{\thanksmarkwidth}{1.8em}
\setlength{\thanksmarksep}{-\thanksmarkwidth}

\AtBeginDocument{%
  \let\thanksrule\footnoterule
  \let\@bsfootnoterule\footnoterule
}

\newlength{\droptitle}
\setlength{\droptitle}{0pt}

\newcommand*{\@pup@titlefootkill}[1]{%
}

\newcommand{\@maketitle}{%
  \let\footnote\@pup@titlefootkill
  \ifdim\pagetotal>\z@
    \newpage
  \fi
  \null
  \vskip 2em%
        \vspace*{\droptitle}
  \maketitlehooka
  {\@bspretitle \thetitle \@bsposttitle}
  \maketitlehookb
  {\@bspreauthor \theauthor \@bspostauthor}
  \maketitlehookc
  {\@bspredate \thedate \@bspostdate}
  \maketitlehookd
  \par
  \vskip 1.5em}

\newenvironment{titlingpage}%
  {\let\footnoterule\relax
   \let\footnotesize\small
   \if@twocolumn
     \@restonecoltrue\onecolumn
   \else
     \@restonecolfalse
   \fi
   \thispagestyle{titlingpage}%
   \setcounter{page}{\@ne}%
  }{%
   \thispagestyle{titlingpage}%
   \if@restonecol \twocolumn \fi
   \if@twoside \cleardoublepage \else \clearpage \fi
   \setcounter{page}{\@ne}}
\thispagestyle{empty}

\newcommand{\emptythanks}{\global\let\@thanks\@empty}

\newcommand*{\andnext}{%
  \end{tabular}\\ \begin{tabular}[t]{c}}

\newcommand{\@bsmtitlempty}{%
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\thanksmarkseries\relax
  \global\let\thanksheadextra\relax
  \global\let\thanksfootextra\relax
  \global\let\thanksmark\relax
  \global\let\thanksgap\relax
}

\newcommand{\keepthetitle}{%
  \@bsmtitlempty
  \global\let\thanks\relax
  \global\let\and\relax
  \global\let\andnext\relax
  \global\let\@thanks\@empty
  \global\let\@title\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
}

\newcommand{\killtitle}{%
  \keepthetitle
  \global\let\thetitle\relax
  \global\let\theauthor\relax
  \global\let\thedate\relax
}


\def\title #1{%
  \begingroup\let\footnote\@gobble%
    \renewcommand{\thanks}[1]{}
    \renewcommand{\thanksmark}[1]{}
    \renewcommand{\thanksgap}[1]{}
    \protected@xdef\thetitle{#1}
\endgroup}

\newcount\authorcount
\newcount\saveauthorcount
\newcount\affilcount
\def\author #1{%
\global\advance\authorcount by 1
  \begingroup\let\footnote\@gobble
    \renewcommand{\thanks}[1]{}
    \renewcommand{\and}{\unskip, }
    \renewcommand{\andnext}{\unskip, }
    \renewcommand{\thanksmark}[1]{}
    \renewcommand{\thanksgap}[1]{}
  \expandafter\gdef\csname author\the\authorcount\endcsname{#1}
  \endgroup}

\def\date #1{%
  \begingroup\let\footnote\@gobble
    \renewcommand{\thanks}[1]{}
    \renewcommand{\thanksmark}[1]{}
    \renewcommand{\thanksgap}[1]{}
    \protected@xdef\thedate{#1}
  \endgroup}

\def\subtitle#1{\gdef\@subtitle{#1}
                \gdef\thesubtitle{#1}
}

\title{}

\subtitle{}

%% No affiliation under authors on title page:
\gdef\affiliation#1{%\global\advance\affilcount by 1
%\expandafter\gdef\csname affil\the\authorcount-\the\affilcount\endcsname{#1}  
}

\newif\if@titlepage
  \@titlepagetrue
 


  \newenvironment{titlepage}%
      {%
        \if@twocolumn
          \@restonecoltrue\onecolumn
        \else
          \@restonecolfalse
        \fi
        \thispagestyle{empty}%
        %%%%%%%%%removed for correct FM pagination \setcounter{page}\@ne
      }%
      {\if@restonecol\twocolumn \else \newpage \fi
       \if@twoside\else
          \setcounter{page}\@ne
       \fi
      }

\newcount\AnnalsNumber

\newcommand\makehalftitle{\begin{titlepage}%
\ifAnnalsOfMath
\vbox to\textheight{
\vglue2.5in
\AOMhalftitlepagefont 
\noindent \hskip24pt Annals of Mathematics Studies
\vskip2pt
\noindent \hskip24pt\AOMhalftitlepagefont 
Number \the\AnnalsNumber\hskip10pt
\vfill
}
\else
 \fontsize{10}{12pt}\selectfont%
   \let\footnotesize\small
   \let\footnoterule\relax
   \let \footnote \thanks
%%
   \begin{flushleft} %\advance\leftskip36pt%
\halftitlepagefont
     \vtop{\ifsevenbyten
\vrule height 49pt width 0pt\else
\vrule height 32pt width0pt\fi
\thetitle 
\par}%
   \end{flushleft}\par
   \@thanks
   \vfil\null
\fi
   \end{titlepage}
}

%%%%% This could certainly be simplified!! ==>>
\newlength{\beforeepigraphskip}
  \setlength{\beforeepigraphskip}{.5\baselineskip}
\newlength{\afterepigraphskip}
  \setlength{\afterepigraphskip}{.5\baselineskip}
\newlength{\epigraphwidth}
  \setlength{\epigraphwidth}{\textwidth}
\newlength{\epigraphrule}
  \setlength{\epigraphrule}{\z@}
\newcommand{\epigraphsize}{\normalsize}
\newcommand{\epigraphflush}{flushright}
\newcommand{\textflush}{flushleft}
\newcommand{\sourceflush}{flushright}
\newcommand{\epigraphfontsize}[1]{\def\epigraphsize{#1}}
\newcommand{\epigraphposition}[1]{\long\def\epigraphflush{#1}}
\newcommand{\epigraphtextposition}[1]{\def\textflush{#1}}
\newcommand{\epigraphsourceposition}[1]{\def\sourceflush{#1}}

\newcommand{\@epirule}{\hspace*{-15\p@}\rule[.5ex]{\epigraphwidth}{\epigraphrule}}
\newcommand{\@epitext}[1]{%
  \begin{minipage}{\epigraphwidth}\begin{\textflush}\leftskip15\p@ #1\\
    \ifdim\epigraphrule>\z@ \@epirule \else \vspace*{1ex} \fi
  \end{\textflush}\end{minipage}}
\newcommand{\@episource}[1]{%
  \begin{minipage}{\epigraphwidth}
    \begin{\sourceflush} #1\end{\sourceflush}
  \end{minipage}}
\newcommand{\epigraph}[2]{\vspace{\beforeepigraphskip}
  {\epigraphsize\begin{\epigraphflush}\begin{minipage}{\epigraphwidth}
    \@epitext{#1}\\ \@episource{---#2}
    \end{minipage}\end{\epigraphflush}
    \vspace{\afterepigraphskip}}}
\newcommand{\qitem}[2]{{%
  \raggedright\item \begin{minipage}{\epigraphwidth}
    \@epitext{#1}\\ \@episource{#2}
  \end{minipage}}}
\newcommand{\qitemlabel}[1]{\hfill}
\newenvironment{epigraphs}{%
  \vspace{\beforeepigraphskip}\begin{\epigraphflush}
  \epigraphsize
  \begin{minipage}{\epigraphwidth}
   \list{}%
    {\itemindent\z@ \labelwidth\z@ \labelsep\z@
     \leftmargin\z@ \rightmargin\z@
     \let\makelabel\qitemlabel}}%
  {\endlist\end{minipage}\end{\epigraphflush}
   \vspace{\afterepigraphskip}}
\newcommand{\dropchapter}[1]{%
  \let\@epichapapp\@chapapp
  \renewcommand{\@chapapp}{\vspace*{#1}\@epichapapp}}
\newcommand{\undodrop}{\let\@chapapp\@epichapapp}
\newif\if@epirhs     \@epirhstrue
\newif\if@epicenter  \@epicentertrue
\newcommand{\@epipos}{
  \long\def\@ept{flushleft}
  \ifx\epigraphflush\@ept
    \@epirhsfalse \@epicenterfalse
  \else
    \long\def\@ept{center}
    \ifx\epigraphflush\@ept
      \@epirhsfalse \@epicentertrue
    \else
      \@epirhstrue  \@epicenterfalse
    \fi
  \fi}
\newcommand{\epigraphhead}[2][95]{%
  \def\@epitemp{\begin{minipage}{\epigraphwidth}#2\end{minipage}}
  \def\ps@epigraph{\let\@mkboth\@gobbletwo
    \@epipos
    \if@epirhs
      \def\@oddhead{\hfil\begin{picture}(0,0)
                         \put(0,-#1){\makebox(0,0)[r]{\@epitemp}}
                         \end{picture}}
    \else
      \if@epicenter
        \def\@oddhead{\hfil\begin{picture}(0,0)
                           \put(0,-#1){\makebox(0,0)[b]{\@epitemp}}
                           \end{picture}\hfil}
      \else
        \def\@oddhead{\begin{picture}(0,0)
                           \put(0,-#1){\makebox(0,0)[l]{\@epitemp}}
                           \end{picture}\hfil}
      \fi
    \fi
    \let\@evenhead\@oddhead
    \def\@oddfoot{\reset@font\hfil\thepage\hfil}
    \let\@evenfoot\@oddfoot}
  \thispagestyle{epigraph}}

\newcommand{\the@epigraph}{}
\newcommand{\@epidrop}{95}
\newcommand{\epigraphforheader}[2][95]{%
  \def\@epidrop{#1}\long\def\the@epigraph{#2}}

\newcommand{\epigraphpicture}{%
  \def\@epitemp{%
    \begin{minipage}{\epigraphwidth}\the@epigraph\end{minipage}}%
  \@epipos
  \if@epirhs
    \begin{picture}(0,0)%
      \put(0,-\@epidrop){\makebox(0,0)[r]{\@epitemp}}%
    \end{picture}%
  \else
    \if@epicenter
      \begin{picture}(0,0)%
        \put(0,-\@epidrop){\makebox(0,0)[b]{\@epitemp}}%
      \end{picture}%
    \else
      \begin{picture}(0,0)%
        \put(0,-\@epidrop){\makebox(0,0)[l]{\@epitemp}}%
      \end{picture}%
    \fi
  \fi}



\newcommand{\epigraphsource}[1]{\vskip.5\baselineskip#1\par}

\newcommand\maketitlepage{\begin{titlepage}%
\global\saveauthorcount\authorcount
\global\advance\saveauthorcount by 1
\authorcount=0
\affilcount=0
    \cleartooddpage\null\thispagestyle{empty}
    \let\footnotesize\small
    \let\footnoterule\relax
    \let \footnote \thanks
    \begin{center}%
      {\par
\ifsevenbyten\vrule height 18pt width0pt\fi
\parskip=0pt
\vglue-38pt %%??
\noindenttwolines
  \bgroup\raggedright %\advance\leftskip30pt
\advance\rightskip18pt
\vrule height 24pt width 0pt
\hrule height 0pt
{\booktitlefont 
\thetitle\vrule depth 24pt width0pt
\vskip1sp
}
\hrule height 0pt
%\vrule height 16pt
  \egroup
  \rule{\textwidth}{.5pt} \par}%
     \end{center}   
  \vskip22pt
  \bgroup
  \let \\\@centercr \@rightskip 18.0pt plus 1.0fil \rightskip
  \@rightskip  %\leftskip28pt%  18pt 
  \parindent0pt
  {\booksubtitlefont
\thesubtitle
\par}
  \vskip48pt
\loop
\global\advance\authorcount by 1
\global\advance\affilcount by 1
\ifnum\authorcount<\saveauthorcount%% test to see if loop should repeat
      {\bookauthorfont
\expandafter\ifx\csname author\the\authorcount\endcsname\relax
\else\vskip1pt
\csname author\the\authorcount\endcsname\fi
       \par}%
\vskip5\p@
      {\fontsize{14}{16pt}\selectfont
          \sffamily\itshape
\expandafter\ifx\csname affil\the\authorcount-\the\affilcount\endcsname\relax  
\else\csname affil\the\authorcount-\the\affilcount\endcsname\fi
\vskip5pt\advance\affilcount by 1
 \expandafter\ifx\csname affil\the\authorcount-\the\affilcount\endcsname\relax  
\else\csname affil\the\authorcount-\the\affilcount\endcsname\fi
\vskip5pt\advance\affilcount by 1
 \expandafter\ifx\csname affil\the\authorcount-\the\affilcount\endcsname\relax  
\else\csname affil\the\authorcount-\the\affilcount\endcsname\fi
\par}
\repeat
\vfill
  %\includegraphics[width=1in]{logo.eps}
  %\vspace{16.4pc}
  \vskip1pc
\princetonfont
  \noindent\hbox to 146pt{P\hss R\hss I\hss N\hss C\hss E\hss T\hss O\hss N\hspace*{7pt}U\hss N\hss I\hss V\hss E\hss R\hss S\hss I\hss T\hss Y\hspace{7pt}P\hss R\hss E\hss S\hss S}\\
  \noindent\hbox to 120pt{P\hss R\hss I\hss N\hss C\hss E\hss T\hss%
  O\hss N\hspace{7pt} A\hss N\hss D\hspace{7pt}O\hss X\hss F\hss O\hss R\hss D}
\ifAnnalsOfMath\vskip3pt
\small\textcopyright\ \ \thecopyrightyear\ \ Princeton University Press\fi
      {\par}%       
  \par
  \egroup
    \@thanks
    \vfil\null
\end{titlepage}
}


\let\@edtby\@empty%
\def\edtby#1{\def\@edtby{#1}\def\theeditor{#1}}%


%%%% <<== End Title Page Commands %%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Copyright Page

\def\copyrightyear#1{\def\thecopyrightyear{#1}}
\def\locNumber#1{\def\thelocNumber{#1}}
\locNumber{}
\def\isbnNumber#1{\def\theisbnNumber{#1}}
\isbnNumber{}
\def\isbnPbkNumber#1{\def\theisbnPbkNumber{#1}}
\isbnPbkNumber{}
\def\Editorial#1{\def\theeditorial{#1}}
\Editorial{}
\def\ProductionEditorial#1{\def\theproductioneditorial{#1}}
\ProductionEditorial{}
\def\TextDesign#1{\def\thetextdesign{#1}}
\TextDesign{}
\def\JacketCoverDesign#1{\def\thejacketcoverdesign{#1}}
\JacketCoverDesign{}
\def\JacketCoverCredit#1{\def\thejacketcovercredit{#1}}
\JacketCoverCredit{}
\def\Production#1{\def\theproduction{#1}}
\Production{}
\def\Publicity#1{\def\thepublicity{#1}}
\Publicity{}
\def\bookcomposed#1{\def\thebookcomposed{#1}}
\bookcomposed{}
\def\typesettingPrintingInformation#1{\def\thetypesettingInfo{#1}}
\typesettingPrintingInformation{}

\def\copyrightpage{
\newpage\bgroup\normalsize\parindent0pt\thispagestyle{empty}\vspace*{5.75pc}
\textcopyright\ \thecopyrightyear\ Princeton University Press
\vspace*{5pt}

Requests for permission to reproduce material from this\newline
work should be sent to Permissions, Princeton University Press

\vspace*{5pt}

Published by Princeton University Press,\newline
41 William Street, Princeton, New Jersey 08540

\vspace*{5pt}

In the United Kingdom: Princeton University Press,\newline
6 Oxford Street, Woodstock, Oxfordshire OX20 1TR

\vspace*{5pt}

{press.princeton.edu}

\vspace*{5pt}

All Rights Reserved

\vspace*{5pt}


\ifx\thelocNumber\empty\else Library of Congress Control Number:
\thelocNumber\fi\vskip2pt
\ifx\theisbnNumber\empty\else ISBN: \theisbnNumber\fi\vskip2pt
\ifx\theisbnPbkNumber\empty\else ISBN (pbk):\theisbnPbkNumber\fi\vskip2pt

\vspace*{5pt}

British Library Cataloging-in-Publication Data is available

\vspace*{5pt}

\ifx\theeditorial\empty\else Editorial: \theeditorial\fi\vskip2pt
\ifx\theproductioneditorial\empty\else Production Editorial: \theproductioneditorial\fi\vskip2pt
\ifx\thetextdesign\empty\else Text Design: \thetextdesign\fi\vskip2pt
\ifx\thejacketcoverdesign\empty\else Jacket/Cover Design:\thejacketcoverdesign\fi\vskip2pt
\ifx\thejacketcovercredit\empty\else Jacket/Cover Credit:\thejacketcovercredit\fi\vskip2pt
\ifx\theproduction\empty\else Production: \theproduction\fi\vskip2pt
\ifx\thepublicity\empty\else Publicity: \thepublicity\fi
\vspace*{5pt}
\ifx\thebookcomposed\empty\else This book has been composed by\ \thebookcomposed\fi
\vspace*{5pt}
Printed on acid-free paper.
\vspace*{5pt}
\ifx\thetypesettingInfo\empty\else\vskip2pt
Typesetting and Printing information:
\thetypesettingInfo\fi
\par\egroup}

%%% <<== End Copyrightpage commands %%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%
%% Dedication       %%%

\newenvironment{dedication}{\clearpage
\thispagestyle{empty}
\normalsize%\fontsize{11}{13.5pt}
\fontsize{11}{14pt}
\selectfont\parindent0pt
\setbox0=\vtop\bgroup
\noindent\ifsevenbyten
\vrule height 49pt width0pt\else
\vrule height 33pt width0pt\fi}
{\egroup\unvbox0\par\newpage}

%%%%%%%%%%%%%%%%%%%%%%%
%% Book Epigraph       %%%

\newenvironment{bookepigraph}{\clearpage
\thispagestyle{empty}
\normalsize% \fontsize{11}{\ifxdraft 24pt\else 13.5pt\fi}
\fontsize{11}{14pt}
\selectfont\parindent0pt
\setbox0=\vtop\bgroup
\noindent\ifsevenbyten\vrule height 50pt width0pt\else
\vrule height 33pt width0pt\fi}
{\egroup\unvbox0\par\newpage}



%%%%%%%%%%%%%%%%%%%%%%%
%% Contributor List %%%
\newenvironment{Contriblist}{\bgroup\parindent\z@%
\def\contrib##1{\vspace{12pt}{\textbf{##1}}\normalsize%
}\let\twolines\noindenttwolines
\chapter*{List of Contributors}%
\shortaddtobrief{LIST OF CONTRIBUTORS}
\bookmark[page=\the\acropage, level=-2]{List of Contributors}
}{\egroup\resetrunninghead}%

%%%%%%%%%%%%%%%%%%%
%% Series Page  %%%

\newenvironment{seriespage}[1][\relax]{
\ifAnnalsOfMath\bgroup
\def\seriesauthor##1{}
\def\title##1{}
\def\author##1{}
\thispagestyle{empty}\vfill\else
\normalsize\thispagestyle{empty}\bgroup\parindent\z@%
{\textbf{\ifsevenbyten
\vrule height 49pt width0pt\else
\vrule height 33pt width0pt\fi
#1}\par\vskip12pt}%
\def\seriesauthor##1{\bgroup\textit{##1}\par\vskip30pt\egroup}%
\def\title##1{\bgroup##1\egroup}%
\def\author##1{\bgroup\textit{##1}\par\vskip7pt\egroup}%
\fi}%
{\egroup}%
%%% End Series Page %%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%
%% Brief Contents

\newwrite\chaptocfile
\let\savedocument\document
\def\document{\savedocument
\global\let\thebibliography\savethebibliography
  \openin\@inputcheck\jobname.chc %
  \ifeof\@inputcheck
\typeout{^^J^^J
!! Please run LaTeX again to get commands for Brief Contents !!^^J^^J}
\else
\input \jobname.chc
\fi
\immediate\openout\chaptocfile=\jobname.chc
}

\newcount\briefnum
\newcount\briefloopnum
\newcommand{\briefcontents}{%
\global\turnoffaddcontentstrue
\startonoddpage
\chapter*{Brief Contents}
\bgroup
\vglue6pt %% Oct 16, 2022
\parindent=0pt
\parskip=6pt
\bookmark[page=\the\acropage, level=0]{Brief Contents}
\bigsmall %% was \small, change Oct 4, 2022
\def\l@chapter##1##2{%
    \vskip 4pt 
     \setlength\@tempdima{2em}% was 1.5
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode
      \advance\leftskip\@tempdima
      \hskip -\leftskip
\rm ##1\nobreak\hfil \nobreak\hbox to\@pnumwidth{\hss\it\space ##2}\par
      \penalty\@highpenalty
    \endgroup\vskip1pt}
\thispagestyle{empty}
%%
\vskip-3pt
\linkcolor
\loop
\global\advance\briefloopnum by 1
\expandafter\ifx\csname contentsinbrief-\the\briefloopnum\endcsname\relax
\else
\vskip.5pt
\expandafter\csname contentsinbrief-\the\briefloopnum\endcsname
\repeat
\vskip1sp
\newpage
\setcounter{tocdepth}{1}
\markboth{}{}
\egroup}

\def\addtobrief#1{
\global\advance\briefnum by 1
\vbox to 0pt{\vss\hypertarget{contentsinbrief-\the\briefnum}
{}
\vskip4in}
\edef\doit{\write\chaptocfile
{\string\expandafter\string\gdef\string\csname\space
contentsinbrief-\the\briefnum\string\endcsname
{\string\hyperlink{contentsinbrief-\the\briefnum}{\string\hbox\space to\space \string\hsize{\string\hbox\space to\space
26pt{\thechapter\string\hfill}\string\vtop{\string\advance\string\hsize
-60pt
{#1}\string\hfill}\string\hfill\string\llap{\string\it\space\noexpand\thepage}}}}}}
\doit}

\def\shortaddtobrief#1{%
\global\advance\briefnum by 1
\vbox to 0pt{\vss\hypertarget{contentsinbrief-\the\briefnum}
{}
\vskip3in}
\edef\doit{\write\chaptocfile
{\string\expandafter\string\gdef\string\csname\space
contentsinbrief-\the\briefnum\string\endcsname
{\string\vskip1pt
\string\hyperlink{contentsinbrief-\the\briefnum}
{\string\hbox\space to\space \string\hsize{\string\bf
\string\vtop{\string\advance\string\hsize
-60pt\space
{#1}\string\hfill}\string\hfill\string\llap{\string\it\space\noexpand\thepage}}}}}}
\doit}

\def\chapshortaddtobrief#1{
\global\advance\briefnum by 1
\vbox to 0pt{\vss\hypertarget{contentsinbrief-\the\briefnum}
{}
\vskip3in}
\edef\doit{\write\chaptocfile
{\string\expandafter\string\gdef\string\csname\space
contentsinbrief-\the\briefnum\string\endcsname
{\string\vskip1pt
\string\hyperlink{contentsinbrief-\the\briefnum}
{\string\hbox\space to\space \string\hsize{\string\rm
\string\vtop{\string\advance\string\hsize
-60pt\space
{#1}\string\hfill}\string\hfill%\string\llap{\string\it\space\noexpand\thepage}
}}}}}
\doit}


\def\partaddtobrief#1{
\global\advance\briefnum by 1
\vbox to 0pt{\vss\hypertarget{contentsinbrief-\the\briefnum}
{}
\vskip3in}
\edef\doit{\write\chaptocfile
{\string\expandafter\string\gdef\string\csname\space
contentsinbrief-\the\briefnum\string\endcsname
{\string\vskip3pt\string\hyperlink{contentsinbrief-\the\briefnum}
{\string\hbox\space to\space \string\hsize{\string\hbox\space to\space
50pt{\string\bf\space PART\space\Roman{part}\string\hfill}\string\vtop{\string\advance\string\hsize
-76pt\string\bf\space
\string\uppercase{#1}\string\hfill}
\string\hfill}}}}
}
\doit}


\def\appendixaddtobrief#1{
\global\advance\briefnum by 1
\vbox to 0pt{\vss\hypertarget{contentsinbrief-\the\briefnum}
{}
\vskip3in}
\edef\doit{\write\chaptocfile
{\string\expandafter\string\gdef\string\csname\space
contentsinbrief-\the\briefnum\string\endcsname
{\string\vskip8pt\string\hyperlink{contentsinbrief-\the\briefnum}
{\string\hbox\space to\space \string\hsize{\string\hbox\space to\space
50pt{\string\bf\space APPENDICES\string\hfill}\string\vtop{\string\advance\string\hsize
-76pt\string\bf\space
\string\uppercase{%#1
}\string\hfill
}}}
\string\vskip-2pt
}}}
\doit

}
%%%% End Brief Contents %%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Table of Contents, List of Figures, List of Tables
%%% List of Algorithms

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Format entries in LOT, LOF, LOA
\newcommand*\l@table{\@dottedtocline{1}{1.5em}{2.3em}}
\newcommand*\l@figure{\@dottedtocline{1}{1.5em}{2.3em}}
\newcommand*\l@algorithm{\@dottedtocline{1}{1.5em}{2.3em}}

\newcommand{\@pnumwidth}{40pt}%{1.85em}
\newcommand{\@tocrmarg} {2.55em}
\newcommand{\@dotsep}{4.5}

\renewcommand{\@starttoc}[1]{%
  \begingroup\makeatletter
\hyphenpenalty=10000
    \@input{\jobname.#1}%
    \if@filesw
      \AtEndDocument{%
       \expandafter\newwrite\csname tf@#1\endcsname
      \immediate\openout \csname tf@#1\endcsname \jobname.#1\relax
       }
    \fi
  \@nobreakfalse
  \endgroup}

\def\numberline#1{\hb@xt@\@tempdima{\bf #1\hfil}}

\newcommand*\l@part[2]{%
  \ifnum \c@tocdepth >-2\relax
    \addpenalty{-\@highpenalty}%
\vskip12pt
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      {\leavevmode\linkcolor
       \large \bfseries PART #1\hfil\par
}\par
       \nobreak
         \global\@nobreaktrue
         \everypar{\global\@nobreakfalse\everypar{}}%
    \endgroup
  \fi\vskip-3pt }

\newcommand*\l@achapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 1.0em \@plus\p@
\vskip4pt
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
{Appendix}   #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi}

\newcommand*\l@chapter[2]{%
  \ifnum \c@tocdepth >\m@ne%
    \addpenalty{-\@highpenalty}%
%    \vskip 1.0em \@plus\p@\vskip2pt%
\vskip9pt
    \setlength\@tempdima{1.5em}%
    \begingroup%
      \parindent \z@ \rightskip \@pnumwidth%
      \parfillskip -\@pnumwidth%
      \leavevmode \bfseries%
      \advance\leftskip\@tempdima%
      \hskip -\leftskip%
     #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par%
      \penalty\@highpenalty%
    \endgroup%
  \fi}

\newcommand*\l@schapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 3pt
\vskip6pt
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss\rm #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi}

\newcommand*\l@ssection[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 3pt
\vskip6pt
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
\hskip\@tempdima\relax#1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi}

\newcommand*\l@section{\vskip2pt\@dottedtocline{1}{1.5em}{2.3em}}
\newcommand*\l@subsection{\@dottedtocline{2}{3.8em}{3.2em}}
\newcommand*\l@subsubsection{\@dottedtocline{3}{7.0em}{4.1em}}
\newcommand*\l@paragraph{\@dottedtocline{4}{10em}{5em}}
\newcommand*\l@subparagraph{\@dottedtocline{5}{12em}{6em}}

%%%% <<== End formatting listings for TOC and similar environments

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Formatting TOC, LOF, LOT
%% part,chapter,section, only in toc:

\setcounter{tocdepth}{1}

\newcommand{\tableofcontents}{%
\clearpage
\leftskip=0pt
\if@twoside 
\ifodd\c@page\else
    \hbox{}\thispagestyle{empty}\newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
  \columnseprule \z@
  \columnsep 35\p@
\global\turnoffaddcontentstrue
  \chapter*{\contentsname}
\bookmark[page=\the\acropage, level=0]{Table of Contents}
{\bigsmall %% was \small, change Oct 4, 2022
 \@starttoc{toc}}%
 \cleartorecto
\resetrunninghead}

\newcommand{\listoffigures}{%
\clearpage\if@twoside 
\ifodd\c@page\else
    \hbox{}\thispagestyle{empty}\newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
  \columnseprule \z@
  \columnsep 35\p@
  \chapter*{\listfigurename}
\bookmark[page=\the\acropage, level=0]{List of Figures}
%\shortaddtobrief{List of Figures}
  \addtocontents{lof}{\relax}%
\@mkboth{\MakeUppercase\contentsname}{\MakeUppercase\contentsname}%
\bigsmall %% change Oct 4, 2022
\vglue-12pt
\vskip1sp
 \@starttoc{lof}%
 \cleartorecto
 \noindent\ignorespaces}
{\if@restonecol\onecolumn\else\clearpage\fi}

%% 
\def\@dottedtocline#1#2#3#4#5{%
\def\@pnumwidth{24pt}
  \ifnum #1>\c@tocdepth \else
    \vskip \z@ \@plus.2\p@
    {\leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
     \parindent #2\relax\@afterindenttrue
     \interlinepenalty\@M
     \leavevmode
     \@tempdima #3\relax
     \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
     {#4}\nobreak
     \leaders\hbox{$\m@th
        \mkern \@dotsep mu\hbox{.}\mkern \@dotsep
        mu$}\hfill
     \nobreak\hb@xt@\@pnumwidth{\hss\normalfont\normalcolor #5}%
     \par}%
  \fi}
\def\numberline#1{\hb@xt@\@tempdima{#1\hfil}}



\newcommand{\listoftables}{%
\clearpage\if@twoside 
\ifodd\c@page\else
    \hbox{}\thispagestyle{empty}\newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
  \columnseprule \z@
  \columnsep 35\p@
  \chapter*{\listtablename}
\vglue-12pt
\vskip1sp
%\shortaddtobrief{List of Tables}
  \addtocontents{lot}{\relax}%
\bookmark[page=\the\acropage, level=0]{List of Tables}
\@mkboth{List of Tables}{List of Tables}%
\bigsmall %% was \small / change Oct 4, 2022
 \@starttoc{lot}%
 \cleartorecto
 \noindent\ignorespaces}
{\if@restonecol\onecolumn\else\clearpage\fi}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Acknowledgments %%%%%%%%%%%%%%%%%%%%%%

\newcommand{\ackname}{Acknowledgments}
\def\acknowledgments{\bgroup%
               \chapter*{\ackname}
%\shortaddtobrief{\string\bf\ Acknowledgments}
\egroup\@afterheading\@afterindentfalse}%
\def\endacknowledgments{\vskip1sp\resetrunninghead}

\let\acknowledgment\acknowledgments
\let\endacknowledgment\endacknowledgments
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Preface
\def\prefaceauthor#1{\vskip3pt\vtop{\begin{flushright}
#1
\end{flushright}}}


\newcommand{\prefacename}{Preface}
\def\preface{\chapter*{Preface}
%\shortaddtobrief{Preface}
\bookmark[page=\the\acropage, level=0]{Preface}
}
\def\endpreface{\resetrunninghead}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Foreword
\def\foreword{%
               \chapter*{Foreword}
%\shortaddtobrief{Foreword}
\bookmark[page=\the\acropage, level=0]{Foreword}
}
\def\endforeword{\resetrunninghead}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Introduction
\def\introduction{%
\@schapter{Introduction}
%\shortaddtobrief{Introduction}
\bookmark[page=\the\acropage, level=0]{Introduction}
}
\def\endintroduction{\resetrunninghead}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Abbreviations, Definitions, Glossary
\long\def\abbreviations{\chapter*{List of Abbreviations}%
\shortaddtobrief{LIST OF ABBREVIATIONS}
\markboth{List of Abbreviations}{List of Abbreviations}
\bookmark[page=\the\acropage, level=-2]{List of Abbreviations}
\bgroup\normalsize
\tabcolsep=0pt
\begin{longtable}{@{\vrule height 14pt width0pt\boldmath\bf}
p{.1\textwidth}p{.9\textwidth}@{}}%
\endfirsthead
%\multicolumn{2}{l}{\bf\relax List of Abbreviations}\\
%\noalign{\hrule width\textwidth}
\endhead
\endfoot
\endlastfoot}
\def\endabbreviations{\end{longtable}\egroup\resetrunninghead}

\long\def\definitions{\chapter*{List of Definitions}%
\shortaddtobrief{LIST OF DEFINITIONS}
\bookmark[page=\the\acropage, level=-2]{List of Definitions}
\bgroup\normalsize
\tabcolsep=0pt
\begin{longtable}{@{\vrule height 14pt width0pt\boldmath\bf}
p{.3\textwidth}p{.7\textwidth}@{}}%
\endfirsthead
%\multicolumn{2}{l}{\bf\relax List of Definitions}\\
%\noalign{\hrule width\textwidth}
\endhead
\endfoot
\endlastfoot}
\def\enddefinitions{\end{longtable}\egroup\resetrunninghead}

\long\def\glossary{\@schapter{Glossary}%
\global\let\currchaptitle\relax
\bookmark[page=\the\acropage, level=-2]{Glossary}
\bgroup\normalsize
\tabcolsep=0pt
\begin{longtable}{@{\vrule height 14pt width0pt\boldmath\bf}
p{.2\textwidth}p{.8\textwidth}@{}}%
\endfirsthead
%\multicolumn{2}{l}{\bf\relax Glossary}\\
%\noalign{\hrule width\textwidth}
\endhead
\endfoot
\endlastfoot}

\def\endglossary{\end{longtable}\egroup\resetrunninghead
\global\let\currchaptitle\relax
}

%%% <<== end abbreviations, list of definitions, glossary

%%%% <<== End Frontmatter %%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 9) Endmatter: Endnotes, Bibliography, Indices 

%%%%%%%%%%%%%%%%%%
%%%% Endnotes

\ifEndnote
\global\let\ChapEndNotes\relax
\usepackage{endnotes}%
\let\saveendnote\endnote
\def\endnote{\ifnum\c@chapter>0 
\write\@auxout{\string\expandafter\string\gdef\string\csname\space
\@chapapp\thechapter Note\string\endcsname{x}}
\fi
\saveendnote}
%%
\let\footnote\endnote%
\def\enoteheading{\chapter*{Notes}%
%%
\thispagestyle{empty}
  \mbox{}\par\vskip-\baselineskip}
\def\enotesize{\normalsize}%
\def\enoteformat{\rightskip\z@ \leftskip16pt 
\@afterindenttrue\parskip\z@\def\@textsuperscript{}%
\vskip2pt
\noindent\hskip-16pt{\hbox to16pt{\hss\makeenmark.\ignorespaces\enskip\hfill}\ignorespaces}}

\def\BookEndNotes{%
\clearpage
\resetrunninghead
\global\endmattertrue
\global\anappendixfalse
\phantomsection
\immediate \closeout \@enotes \global \@enotesopenfalse \begingroup
\makeatletter  \edef \@tempa {`\string >}\ifnum \catcode \@tempa =12\let \@ResetGT \relax
 \else \edef \@ResetGT {\noexpand \catcode \@tempa =\the \catcode
 \@tempa }\@makeother \>\fi  \leftskip=0pt
\def \@doanenote ##1##2>{\def \@theenmark {##1}\par \begingroup 
\@ResetGT \edef \@currentlabel {\csname\space p@endnote\endcsname
\@theenmark } \enoteformat } 
\def \@endanenote {\par \endgroup }\enoteheading \enotesize 
\bookmark[page=\the\acropage, level=-2]{Book End Notes}
\shortaddtobrief{BOOK END NOTES}
\def\currchaptitle{Book End Notes}
%\plainaddcontentsline{toc}{schapter}{Notes}%
\input {\jobname.ent}\endgroup\resetrunninghead}
%
\else\let\endnotes\relax
\newcommand\@makefntext[1]{%
    \parindent 1em%
    \noindent
    \hb@xt@1.8em{\hss\@makefnmark}#1}
\fi% ends \ifendnote (set in options)

%%%% End Book Endnotes %%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Bibliography

\newdimen\bibindent
\setlength\bibindent{\parindent}
\ifAnnalsOfMath
\def\@biblabel#1{[#1]}
\def\@lbibitem[#1]#2{\item[{[#1]}\hfill]
\if@filesw
      {\let\protect\noexpand
       \immediate
      \write\@auxout{\string\bibcite{#2}{#1}}}\fi\ignorespaces}
\else
\def\@lbibitem[#1]#2{\item[{[#1]}\hfill]\if@filesw
      {\let\protect\noexpand
       \immediate
      \write\@auxout{\string\bibcite{#2}{#1}}}\fi
\ignorespaces}
\fi

\newenvironment{thebibliography}[1]
{\phantomsection\startonoddpage
\global\anappendixfalse
\chapter*{Bibliography}
\gdef\currchaptitle{Bibliography}
\markboth{Bibliography}{Bibliography}
\bookmark[page=\the\acropage, level=-2]{Bibliography}
\small
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy\clubpenalty4000\widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist
\newpage
\thispagestyle{empty}
}
%

\newcommand\newblock{\hskip .11em\@plus.33em\@minus.07em}
\let\@openbib@code\@empty
%%%% <<== End Bibliography %%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Index or Multiple Indices

\ifmultipleindices
\usepackage{multind}
\gdef\printindex#1#2{%
\global\endmattertrue
\thispagestyle{empty}
\twocolumn[\@makeschapterhead{\uppercase{#2}}]%
\bookmark[page=\the\acropage, level=-2]{#2}
\def\currchaptitle{#2}
%\shortaddtobrief{#2}
%\addcontentsline{toc}{schapter}{#2}%
\@input {#1.ind}
\onecolumn}
\else
%% This makes the standard, single index for the end of the book:
\usepackage{makeidx}
\makeindex

\newenvironment{theindex}
               {\phantomsection
\startonoddpage
\global\endmattertrue
\global\anappendixfalse\if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
\resetrunninghead
\gdef\currchaptitle{INDEX}
                \columnseprule \z@
                \columnsep 35\p@
\small
\leftskip=0pt
\let\twolines\noindenttwolines
              \twocolumn[\vglue30pt % +++
\@makeschapterhead{\indexname}]%
\bookmark[page=\the\acropage, level=-2]{Index}
\shortaddtobrief{INDEX}
                \thispagestyle{empty}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem
\vskip-\baselineskip %% change Oct 6, 2022, to make both
         %% columns on first page of index start at same height.
}
               {\if@restonecol\onecolumn\else\clearpage\fi}
\newcommand\@idxitem{\par\hangindent 40\p@}
\newcommand\subitem{\@idxitem \hspace*{20\p@}}
\newcommand\subsubitem{\@idxitem \hspace*{30\p@}}
\fi

%%%% <<== End Index or Multiple Indices %%%%%%%%%

%%%% <<== End Endmatter %%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 10) Part and Chapter Commands 

\newif\ifanappendix
  \anappendixfalse
\newcommand{\appendix}{\par
\global\endmattertrue
\global\let\theauthor\relax
\global\let\thesubtitle\relax
%% need this but it messes up the index hyperlinking!
%\hypersetup{hypertexnames=false}
%\thispagestyle{empty}
\def\currchaptitle{}
  \setcounter{chapter}{0}%
  \setcounter{section}{0}%
  \gdef\@chapapp{APPENDIX}%
\appendixaddtobrief{}
  \gdef\thechapter{\@Alph\c@chapter}%
  \anappendixtrue}

\newlength{\beforechapskip}\setlength{\beforechapskip}{50pt}
\newlength{\midchapskip}\setlength{\midchapskip}{20pt}
\newlength{\afterchapskip}\setlength{\afterchapskip}{40pt}
\newlength{\chapterdrop}
\setlength{\chapterdrop}{8.5pt}

\newlength{\schapterdrop}
\setlength{\schapterdrop}{6.34pt}

\newlength{\partdrop}
\setlength{\partdrop}{0pt}


\def\partepigraph#1#2{\gdef\thepartepi{\chapepigraph{\hsize=.9\textwidth\relax#1}{#2}}}

\newcommand\part{%
\startonoddpage
\secdef\@part\@spart}

\def\@part[#1]#2{%
\ifnum\c@part=0\mainmatter\fi
\global\mainmattertrue
\resetrunninghead
      \refstepcounter{part}%
      \plainaddcontentsline{toc}{part}{\thepart\hspace{1em}#1}%
\def\one{#1}
\ifx\one\empty
\bookmark[page=\the\acropage, level=-2]{Part \thepart: #2}
\else
\bookmark[page=\the\acropage, level=-2]{Part \thepart: #1}
\fi
    \markboth{}{}%
\partaddtobrief{#1}
%     \interlinepenalty \@M
%     \normalfont
%
   \vtop{\partnumfont 
\noindent\ifsevenbyten
\vrule height 38pt width0pt depth14pt \else
\vrule height 22pt width0pt depth14pt \fi
\partname~\thepart
\par}%
\noindenttwolines
\vglue20pt
{\parttitlefont
\noindent#2
\vskip1sp}%
\vskip36pt%
\@endpart
}%%

\def\@endpart{\expandafter\ifx\csname\space thepartepi\endcsname\relax
\else\csname\space thepartepi\endcsname\fi
\global\let\thepartepi\relax\resetrunninghead\newpage\interlinepenalty=0
\newpage
\thispagestyle{empty}
\ \ 
\newpage
}

%%%% <<== end Part commands %%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Chapter commands %%%%%%%%%%%%%%%%%%%%%%%%%

\newif\iffirstchapepi
\firstchapepitrue
\long\def\chapepigraph#1#2{\iffirstchapepi\global\firstchapepifalse\vskip12pt\else\vskip-12pt\fi
\hbox to \textwidth{\hskip18pt\vtop{\raggedright
\advance\hsize-24pt  #1\vskip1sp}}\vskip3pt
\ifxdraft\vskip10pt\fi
\hbox to\textwidth{\hfill---\relax #2}\vskip12pt}

\let\@affil\@empty%
\def\chapaffiliation#1{\def\@affil{#1}}%

\def\twolines{\vskip-15pt\noindent\hskip-15pt\vtop{%
  \rule{\textwidth}{2pt}\vskip-7pt
  \rule{\textwidth}{.5pt}\par}\vskip18pt}

\def\noindenttwolines{\noindent%\vrule height \universaldrop
\vtop{%
\hrule width \textwidth height 2pt
\vskip4pt
\hrule width \textwidth height .5pt
\par
}\vskip1sp}

\let\savefootnote\footnote

\newcommand\chapter{\startonoddpage
\thispagestyle{empty}
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
\let\@chapauth\@empty
\def\chapauthor#1{\def\@chapauth{#1}}%
%%
\newif\iffirstappendix
\global\firstappendixtrue
\newif\ifappendbookmark
\appendbookmarktrue
\newif\ifanappendix
  \anappendixfalse
\let\saveaddcontentsline\addcontentsline

\def\thanks#1{}
\def\eatone#1{}

\def\@chapter[#1]#2{%% 
%%%
\ifnum\c@chapter=0\ifmainmatter %% there is a \part before first \chapter
\else\mainmattertrue\fi\fi
\def\one{#1}\def\two{#2}
\ifx\one\two \let\one\empty\fi
\let\addcontentsline\plainaddcontentsline
\ifx\one\empty
  \ifx\two\empty\gdef\currchaptitle{\@chapapp}
  \else\gdef\currchaptitle{\uppercase{#2}}\fi
\else
\gdef\currchaptitle{\uppercase{#1}}
\fi
\setcounter{endnote}{0}
\ifnum \c@secnumdepth >\m@ne
                         \ifmainmatter
                         \refstepcounter{chapter}%
\ifanappendix
\iffirstappendix\global\firstappendixfalse
\addtocontents{toc}{{\string\large\string\vskip18pt\string\linkcolor\string\noindent\space\string\bf\space
Appendices\string\vskip-3pt}}\fi
\ifappendbookmark\global\appendbookmarkfalse
\bookmark[page=\the\acropage, level=-2]{Appendices}
\fi
\fi\fi
\ifanappendix
\markboth{Appendix \thechapter}{Appendix \thechapter}
\ifx\one\empty
\bookmark[page=\the\acropage, level=-1]{Appendix \thechapter. #2}
\else
\bookmark[page=\the\acropage, level=-1]{Appendix \thechapter. #1}
\fi
\else
\ifx\one\empty
\bookmark[page=\the\acropage, level=0]{\thechapter. #2}
\else
\bookmark[page=\the\acropage, level=0]{\thechapter. #1}
\fi
\fi
   \typeout{\@chapapp\space\thechapter.}%
\ifEndnote
\expandafter\ifx\csname\space \@chapapp\thechapter Note\endcsname\relax\else
\ifx\one\empty
\addtoendnotes{\protect\section*{\@chapapp~\thechapter\quad 
#2}}
\else
\addtoendnotes{\protect\section*{\@chapapp~\thechapter\quad 
#1}}\fi\fi\fi
                 %% secnumdepth > m@ne
\ifmainmatter
                 %% mainmatter true
             \ifanappendix
                         \ifx\one\empty
            \addcontentsline{toc}{achapter}%
                                   {\protect\numberline{\thechapter}#2}%
             \else
           \addcontentsline{toc}{achapter}%
                                   {\protect\numberline{\thechapter}%\protect\\
				  #1}%
            \fi
            \else %% not appendix
            \addcontentsline{toc}{chapter}{\protect\numberline{\thechapter}#1}%
            \fi
       \else %% not mainmatter
             \ifanappendix
             \ifx\one\empty
              \addcontentsline{toc}{achapter}%
                                   {\protect\numberline{\thechapter}#2}%
              \else
              \addcontentsline{toc}{achapter}%
                                   {\protect\numberline{\thechapter}#1}%
              \fi
     \else %% not appendix
     \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\thechapter}#1}%
     \fi
\else %% not mainmatter
                         \addcontentsline{toc}{chapter}{#1}%
\fi
 %                      \fi
                    \else %% secnumdepth not greater than -1
                     \addcontentsline{toc}{chapter}{#1}%
                  \fi
                  %  \chaptermark{#1}%
                    \addtocontents{lof}{\protect\addvspace{10\p@}}%
                    \addtocontents{lot}{\protect\addvspace{10\p@}}%
%%
%%
\let\footnote\eatone \@makechapterhead{#2}%
\global\let\footnote\savefootnote
                      \@afterheading
}

\let\currchaptitle\relax
\def\@makechapterhead#1#2{
\addtobrief{#1} % <<== probably the right place for this
\def\thanks##1{\typeout{^^J^^J\string\thanks\string{\string} not allowed in
chapter title^^J^^J}} 
\def\footnote##1{\typeout{^^J^^J
\string\footnote\string{\string} not allowed in chapter title^^J^^J}}
\vglue-2pt
  {\parindent 0pt \raggedright 
\ifnum\c@chapter=1
\ifanappendix\else
\ifnum\c@part=1\else
\chapshortaddtobrief{\string\vskip-\parskip}\fi\fi\fi
%\addtobrief{#1} %added earlier ??
\chapnumberfont
       \noindent\ifsevenbyten\vrule height 30pt width0pt\fi\ifanappendix Appendix 
\else Chapter\vrule depth 14pt width0pt\fi%
\ifanappendix\thechapter\ \else\ 
\ifcase\the\c@chapter\or%
One\or Two\or Three\or Four\or Five\or%
Six\or Seven\or Eight\or Nine\or Ten\or%
Eleven\or Twelve\or Thirteen\or Fourteen\or Fifteen\or%
Sixteen\or Seventeen\or Eighteen\or Nineteen\or Twenty\or%
Twenty One\or Twenty Two\or Twenty Three\or Twenty Four\or Twenty Five\or%
Twenty Six\or Twenty Seven\or Twenty Eight\or Twenty Nine\or Thirty\or%
Thirty One\or Thirty Two\or Thirty Three\or Thirty Four\or Thirty Five\or%
Thirty Six\or Thirty Seven\or Thirty Eight\or Thirty Nine\or Forty\or%
Forty One\or Forty Two\or Forty Three\or Forty Four\or Forty Five\or%
Forty Six\or Forty Seven\or Forty Eight\or Forty Nine\or Fifty\or%
\else
Ask for help if you need more Chapter numbers!
\fi%ifcase
\fi% ifanappendix
}        \par
\noindenttwolines
%\vskip24pt
\vskip20pt
%   \fi% if mainmatter??
   \interlinepenalty\@M
\leftskip=0pt
   {\raggedright
\chaptitlefont\noindent#1\vskip2pt}\nobreak
\ifx\thesubtitle\@empty\relax\else
%  \typeout{Do not use \string\subtitle\space 
%following chapter title \MessageBreak
%Chapter subtitle not allowed}
{\chapsubtitlefont\vskip14pt\noindent\vrule
height18pt width0pt\thesubtitle\par}
\fi
\gdef\thesubtitle{}%
\ifx\theauthor\@empty\else
{\chapauthorfont\vskip3pt\noindent\theauthor\par}\gdef\theauthor{}\fi
\vskip36pt
\interlinepenalty=0
\global\leftskip=0pt\@afterheading}
\gdef\theauthor{}

\def\@schapter#1{\clearpage\@makeschapterhead{#1}%
\@afterheading}

\newif\ifturnoffaddcontents
\def\@makeschapterhead#1{%
\ifAnnalsOfMath\startonoddpage\fi
\markboth{#1}{#1}
\ifturnoffaddcontents\global\turnoffaddcontentsfalse
\else
\vbox to
0pt{\vss\plainaddcontentsline{toc}{schapter}{#1}\vskip3in}%
\fi
\thispagestyle{empty}
{\gdef\currchaptitle{\MakeUppercase{#1}}}
\ifsevenbyten\vglue-5pt\else\vglue-21pt \fi
\noindenttwolines
  {\parindent \z@ \raggedright
    \interlinepenalty\@M
{\schapterfont
\vglue3pt
\noindent\relax\rlap{#1}\par\nobreak
    \vskip 43\p@
 }
\normalfont}\interlinepenalty=0\relax}



\def\footnoterule{\vskip6pt%\kern-3\p@
  \hrule \@width 2in \kern 2.6\p@} % the \hrule is .4pt high



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Chapter End Notes

\ifChapEndnote

\global\let\BookEndNotes\relax

\@addtoreset{footnote}{chapter}

\long\def\@makefntext#1{%
    \parindent 1em%
    \noindent
    \@makefnmark#1}

\newcount\footnum
\newcount\savefootnum
\def\endnote#1{\global\advance\footnum by 1\relax$^{\the\footnum}$%
\long\expandafter\gdef\csname\space foot\the\footnum\endcsname{%
\vtop{\small\hsize=\textwidth\leftskip=12pt\relax\parindent=-12pt
\indent\hbox to12pt{\the\footnum.\hfill}{#1\strut\vskip1sp}}\vskip1pt}}

\let\footnote\endnote

\def\endnotetext#1{\global\advance\footnum by 1\relax
\long\expandafter\gdef\csname\space foot\the\footnum\endcsname{%
\vtop{\small\hsize=\textwidth\leftskip=12pt\relax\parindent=-12pt
\indent\hbox to12pt{\the\footnum.\hfill}{#1\strut\vskip1sp}}\vskip1pt}}


\def\ChapEndNotes{\ifnum\footnum=0\else
\savefootnum=\footnum
\footnum=0
\phantomsection
\section*{Chapter End Notes}
\bookmark[page=\the\acropage, level=3]{End Notes}
%\plainaddcontentsline{toc}{ssection}{End Notes}%
\noindent\loop\ifnum\savefootnum>\footnum%
\global\advance\footnum by1\relax%
\csname\space foot\the\footnum\endcsname\relax%
\expandafter\gdef\csname\space foot\the\footnum\endcsname{\relax}\relax%
\repeat\global\footnum=0\relax\fi}
\fi

%%% End Chapter Endnotes %%%%%%%%%%%%%%%%%%%%%%%%%


%%% <<== End Part and Chapter Commands %%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 11) Section Commands

%% from latex.ltx, modified to include section heads in bookmarks.
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
%% 
\def\sendbookmark{\bookmark[page=\the\acropage,
level=2]{\thesection\ #7}}
\ifnum #2=1 \let\go\sendbookmark\else\let\go\relax\fi\go
%%
    \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #6{%
        \@hangfrom{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M #8\@@par}%
    \endgroup
%% ++++ below makes the section title repeat!
%   \csname\space #1mark\endcsname{#7}%
    \plainaddcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth \else
        \protect\numberline{\csname%\space 
the#1\endcsname}%
      \fi
     #7}%
  \else
    \def\@svsechd{%
      #6{\hskip #3\relax
      \@svsec #8}%
      \csname\space #1mark\endcsname{#7}%
      \addcontentsline{toc}{#1}{%
        \ifnum #2>\c@secnumdepth \else
          \protect\numberline{\csname %\space 
the#1\endcsname}%
        \fi
   #7}}%
  \fi
  \@xsect{#5}\interlinepenalty=0\relax}

\newskip\aftersectionskip
\aftersectionskip=12pt

\newskip\smaftersectionskip
\smaftersectionskip=8pt

%% keep this version of section heads
\newcommand\section{\def\@seccntformat##1{\noindent
\hbox to27pt{\csname%\space 
the##1\endcsname\hfill}}
\@startsection {section}{1}{0pt}%
                                   {-12pt}%
                                   {\aftersectionskip}
                                   {\boldmath\sectionfont\MakeUppercase}}


\newcommand\subsection{\def\@seccntformat##1{\csname %\space
the##1\endcsname\ \ \ \ }
\@startsection{subsection}{2}{\z@}%
                                   {-10pt}%
                                   {\smaftersectionskip}%
                                   {\noindent\boldmath\vrule height
				   16pt width 0pt\subsectionfont}}

\newcommand\subsubsection{\def\@seccntformat##1{\csname %\space
the##1\endcsname\ \ \ \ }
\@startsection{subsubsection}{3}{\z@}%
                                   {-10pt}%
                                   {\smaftersectionskip}%
                                   {\boldmath\subsubsectionfont}}

%\let\savesubsubsection\subsubsection

\newcommand\paragraph{\def\@seccntformat##1{\csname%\space 
the##1\endcsname\
\ \ \ }
\@startsection{paragraph}{4}{\z@}%
                                    {-10pt}%-3pt plus 1pt minus 1pt}%
                                    {4pt}%
                                    {\boldmath\paragraphfont}}

\newcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                    {-3pt plus 1pt minus 1pt}%
                                    {-1em}%
                                      {\normalfont\normalsize\itshape\subparagraphfont}}

%%% <<== End Section Commands %%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 12) Running Heads, Crop Marks

%%%%%%%%%%%%%%%%
%% Running Heads

\def\markboth#1#2{\def\xone{#1}\def\xtwo{#2}
\ifx\xone\empty\gdef\currevenhead{}\else
\gdef\currevenhead{\MakeUppercase{#1}}\fi
\ifx\xtwo\empty\gdef\curroddhead{}\else
\gdef\curroddhead{\MakeUppercase{#2}}\fi}
\markboth{}{}

\def\markright#1{\def\currchaptitle{\MakeUppercase{#1}}}

\renewcommand{\@chapapp}{CHAPTER}

\def\ps@PUPheadings{%
    \let\@oddfoot\@empty\let\@evenfoot\@empty
%%
\def\@evenhead{{\hbox to -4pt{}%% changed to -4 from -6pt Oct 6, 2022
\foliofont\thepage\hfill
{\normalfont\fontsize{8}{10pt}\selectfont\sffamily
\ifx\currevenhead\empty
\ifnum\c@chapter<1 \currchaptitle\else
\ifanappendix\currchaptitle\else\ifendmatter\currchaptitle\else\@chapapp\
\thechapter\fi\fi\fi\else\currevenhead\fi}}}
%%
\def\@oddhead{\hskip1pt{\runningheadfont
\ifx\curroddhead\empty
\expandafter\ifx\csname\space currchaptitle\endcsname\relax%
\else\currchaptitle \ifanappendix\ \thechapter\fi\fi
\else
\curroddhead\fi
\hfill
\foliofont\thepage}}
%%
}



\def\resetrunninghead{\clearpage\thispagestyle{empty}\global\let\currchaptitle\relax
\markboth{}{}
\gdef\currtitle{}
}

%%%%%%%%%%%%
%% Cropmarks
\newdimen\paperheight
\newdimen\paperwidth

\paperheight=11in
\paperwidth=8.5in

\def\widedash{\ \raise.5pt\hbox{---}\ }

\newif\iftesting

\ifnocropmarks
\else

%%with trim-mark
\RequirePackage[info,letter,center,cam]{crop}
%
\renewcommand*\CROP@@info{
    \global\advance\CROP@index\@ne
    \def\x{\discretionary{}{}{\hbox{\kern.5em---\kern.5em}}}%
    \advance\paperwidth-20\p@
    \dimen@4pt
    \ifx\CROP@pagecolor\@empty
    \else
        \advance\dimen@\CROP@overlap
    \fi
    \hb@xt@\z@{%
        \hss
        \vbox to\z@{%
             %\centering
            \hsize\paperwidth
            \vss
            \normalfont
            \footnotesize
            \expandafter\csname\CROP@font\endcsname{%
\iftesting
 \noindent\hbox to\paperwidth{%
 \vtop to 0pt{\vskip6pt\hsize=1pt\vrule depth \universaldrop height 0pt\vss}
 \hskip-3pt
 \ifodd\c@page\hbox to .75in\else\hbox to 3.25pc\fi%
 {\vrule height12pt\hrulefill\ifodd\c@page .75in\else 3.25pc\fi
 \hrulefill\vrule height12pt}%
 \hrulefill \ifsixbynine6x9\hrulefill\ifstixfonts STIX/Helvetica Fonts\else
 Times/Helvetica Fonts\fi\else 7x10\hrulefill\ifstixfonts STIX/Helvetica Fonts\else
 \hrulefill Times/Helvetica Fonts\fi
 \fi\hrulefill%
 \ifodd\c@page\hbox to 3.25pc \else\hbox to .75in\fi%
  {\vrule height12pt\hrulefill\ifodd\c@page 3.25pc\else
  .75in\fi\hrulefill\vrule height 12pt}% 
 }%
\else
\noindent\hbox
to\paperwidth{\hskip10pt\hfill\scriptsize\bf\ifsixbynine6.125 x 9.25 in size\else%
\ifsevenbyten 7 x 10 in size\fi\fi%
\widedash\jobname.tex\widedash PUP-Book.cls\widedash
Princeton University Press\widedash\today\widedash\CROP@time\widedash
Page-\thepage\strut%
         \ifsevenbyten\ \ \fi\hfill\hskip10pt}%
\fi %% end \iftesting
  \vskip\dimen@
        }}%
        \hss
    }%
}
\fi%% <-- end conditional test for no cropmarks


%%% <<== End Running Heads, Crop Marks %%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 13) Listing

\@beginparpenalty -\@lowpenalty
\@endparpenalty   -\@lowpenalty
\@itempenalty     -\@lowpenalty

\def\@listI{\leftmargin\leftmargini
%\parskip=0pt
            \parsep 0\p@ %\@plus2\p@ \@minus0\p@
            \topsep 4\p@ %\@plus2\p@ \@minus0\p@
            \itemsep1\p@ %\@plus2\p@ \@minus0\p@
}
\let\@listi\@listI
\@listi
\def\@listii {\leftmargin\leftmarginii
              \labelwidth\leftmarginii
              \advance\labelwidth-\labelsep
              \topsep    4\p@ \@plus2\p@ \@minus\p@
              \parsep    2\p@ \@plus\p@  \@minus\p@
              \itemsep   \parsep}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep
              \topsep    2\p@ \@plus\p@\@minus\p@
              \parsep    \z@
              \partopsep \p@ \@plus\z@ \@minus\p@
              \itemsep   \topsep}
\def\@listiv {\leftmargin\leftmarginiv
              \labelwidth\leftmarginiv
              \advance\labelwidth-\labelsep}
\def\@listv  {\leftmargin\leftmarginv
              \labelwidth\leftmarginv
              \advance\labelwidth-\labelsep}
\def\@listvi {\leftmargin\leftmarginvi
              \labelwidth\leftmarginvi
              \advance\labelwidth-\labelsep}

  %% amount left edge of text is indented relative to normal text
  %% i is for first level in, ii is for second level in, etc.
%\setlength\leftmargini  {36pt}
\setlength\leftmargini{12pt}
\setlength\leftmarginii {14pt}% {11pt} change Oct 5, 2022
\setlength\leftmarginiii {1.87em}
\setlength\leftmarginiv  {1.7em}
\setlength\leftmarginv  {1em}
\setlength\leftmarginvi {1em}


  %% default indentation for first level itemized lists
\setlength\leftmargin    {\leftmargini}

  %% horizontal distance between item and following text
\setlength  \labelsep  {6pt}

  %% how wide should item be?
\setlength  \labelwidth{\leftmargini}

  %% subtract width of label separation
\addtolength\labelwidth{-\labelsep}

  %% more listing defaults
\leftmargin\leftmargini
\labelwidth\leftmargini\advance\labelwidth-\labelsep

\newenvironment{description}
               {\list{}{\labelwidth\z@ \itemindent-\leftmargin
                        \let\makelabel\descriptionlabel}}
               {\endlist}
\newcommand*\descriptionlabel[1]{\hspace\labelsep
                                \normalfont\bfseries #1}

\newenvironment{unnumberedlist}{\begin{list}
{}%%%%no label
{%%%%%no counter
\setlength{\topsep}{6pt}%
\setlength{\partopsep}{0pt}%
\setlength{\parsep}{0pt}%
\setlength{\itemsep}{6pt}%
\setlength{\leftmargin}{\leftmargini}%
\setlength{\rightmargin}{0pt}%
\setlength{\listparindent}{0pt}%
\setlength{\labelwidth}{0pt}%
\setlength{\itemindent}{-12pt}%
\setlength{\labelsep}{0pt}}}%
{\end{list}}

\let\unnumberlist\unnumberedlist
\let\endunnumberlist\endunnumberedlist

%% default lists
\def\@listi{\leftmargin\leftmargini
%  \parsep\parsepi
 % \topsep\topsepi
  %\itemsep\itemsepi
}
\let\@listI\@listi

\@listi

\def\@listii{\leftmargin\leftmarginii
             \labelwidth\leftmarginii
             \advance\labelwidth-\labelsep
%             \topsep\topsepii
%             \parsep\parsepii
             \itemsep\parsep}

\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep
%              \topsep\topsepiii
              \parsep\z@
              \partopsep \p@ 
              \itemsep\topsep}

\def\@listiv{\leftmargin\leftmarginiv
             \labelwidth\leftmarginiv
             \advance\labelwidth-\labelsep}

\def\@listv{\leftmargin\leftmarginv
            \labelwidth\leftmarginv
            \advance\labelwidth-\labelsep}

\def\@listvi{\leftmargin\leftmarginvi
             \labelwidth\leftmarginvi
             \advance\labelwidth-\labelsep}

\renewcommand{\theenumiv}{\@Alph\c@enumiv}
\newcommand{\labelenumi}{\theenumi.}
\newcommand{\labelenumii}{\theenumii)}
\newcommand{\labelenumiii}{\theenumiii.}
\newcommand{\labelenumiv}{\theenumiv.}

\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\renewcommand\theenumiv{\@Alph\c@enumiv}

\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}

\newcommand\labelitemi{\textbullet}
\newcommand\labelitemii{\normalfont\bfseries
\llap{\textendash\hskip3pt}}
\newcommand\labelitemiii{\textasteriskcentered}
\newcommand\labelitemiv{\textperiodcentered}


%%% <<== End Listing %%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 14) Figure and Table Floats and Captions 

\newcounter{figure}
\renewcommand
\thefigure{\ifnum\c@chapter>0\thechapter.\fi\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{Figure~\thefigure}
\newenvironment{figure}
               {\@float{figure}}
               {\end@float}
\newenvironment{figure*}
               {\@dblfloat{figure}}
               {\end@dblfloat}

% already defined, \newcounter{table}, in longtable presumably
\renewcommand
\thetable{%\ifappendix\@Alph\c@section.\fi
\ifnum\c@chapter>0\thechapter.\fi\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{3}
\def\ext@table{lot}
\def\fnum@table{Table~\thetable}
\newenvironment{table}
               {\@float{table}}
               {\end@float}
\newenvironment{table*}
               {\@dblfloat{table}}
               {\end@dblfloat}
\newlength\abovecaptionskip
\newlength\belowcaptionskip
\setlength\abovecaptionskip{10\p@}
\belowcaptionskip=7pt %% changed to 7pt Oct 6, 2022

\def\caption{%
   \ifx\@captype\@undefined
     \@latex@error{\noexpand\caption outside float}\@ehd
     \expandafter\@gobble
   \else
     \refstepcounter\@captype
     \expandafter\@firstofone
   \fi
   {\@dblarg{\@caption\@captype}}%
}

\newenvironment{tablenote}{\bgroup\par\vspace{4.5\p@}%
\footnotesize}{\vskip1sp\egroup}

% new, oct 2, 2023
\long\def\@caption#1[#2]#3{%
  \par
  \addcontentsline{\csname %\space 
ext@#1\endcsname}{#1}%
    {\protect\numberline{\csname %\space 
the#1\endcsname}{\ignorespaces #2}}%
  \begingroup
    \@parboxrestore
    \if@minipage
      \@setminipage
    \fi
    \normalsize
    \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
  \endgroup}

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1: #2}%
  \ifdim \wd\@tempboxa >\hsize
#1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi\vskip\belowcaptionskip}

%%% <<== End Figure and Table Captions %%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 15) Colors 

%% to get illustrations to print, in spite of being in Draft mode:
%\setkeys{Gin}{draft=false}

\RequirePackage{xcolor}%
\colorlet{shadecolor}{black!10}%
\definecolor{ltgray}{cmyk}{0,0,0,.6}
\definecolor{newverydkcyan}{cmyk}{1,0,0,.4}
\def\linkcolor{\color{black}}


%%% <<== End Colors %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 16) Shaded Code (verbatim), and Framebox

%\def\verbatim@font{\fontsize{9.5}{12}%
%\fontspec{CourierStd.otf}}
\def\verbatim@font{\fontsize{10}{12}\ttfamily}

%% \verbatim@font added before \catcode`\ =\active
%% to get the right width between words
{\verbatim@font\catcode`\ =\active%
\gdef\@vobeyspaces{\catcode`\ \active\let \@xobeysp}}
\begingroup \catcode `|=0 \catcode `[= 1
\catcode`]=2 \catcode `\{=12 \catcode `\}=12
\catcode`\\=12
|gdef|@xverbatim#1\end{verbatim}[#1|end[verbatim]]
|gdef|@sxverbatim#1\end{verbatim*}[#1|end[verbatim*]]
|endgroup
\def\@verbatim{\trivlist \item\relax
  \if@minipage\else\vskip\parskip\fi
  \leftskip\@totalleftmargin\rightskip\z@skip
  \parindent\z@\parfillskip\@flushglue\parskip\z@skip
  \@@par
  \@tempswafalse
  \def\par{%
    \if@tempswa
      \leavevmode \null \@@par\penalty\interlinepenalty
    \else
      \@tempswatrue
      \ifhmode\@@par\penalty\interlinepenalty\fi
    \fi}%
  \let\do\@makeother \dospecials
  \obeylines \verbatim@font \@noligs
  \hyphenchar\font\m@ne
  \everypar \expandafter{\the\everypar \unpenalty}%
}

\let\saveverbatim\verbatim
\let\saveendverbatim\endverbatim

%% Adding shading behind code examples, except if \noshading is used:

\newif\ifnoshading
\newif\ifalwaysnoshading
\def\noshading{\global\noshadingtrue}
\def\NeverVerbatimShading{\gdef\startshading{}
\gdef\endshading{}}

\def\startshading{\fboxsep=0pt\shaded
\vskip12pt
\vbox to-20pt{}}
\def\endshading{\vskip-12pt\endshaded}

%% Turning color of shading to white if \noshading has been used,
%% for one instance of code.
%%
%% \NeverVerbatimShading the shading will for verbatim will be
%% turned off for whole document.
%%

\def\verbatim{\ifnoshading\global\noshadingfalse
\colorlet{shadecolor}{white}\fi
\startshading\saveverbatim}
\def\endverbatim{\saveendverbatim\endshading}

\RequirePackage{xcolor}%
\colorlet{shadecolor}{black!10}%

\definecolor{newverydkcyan}{cmyk}{1,0,0,.4}

%%
\usepackage{framed}%
\def\textadjustwidth{\advance \hsize by -2\FrameSep}%

%% Adding \textadjustwidth in definition of shaded
%% shortens width of text so that shading is on the text edge
%% not out in the margin:
\let\shaded\relax
\long\def\shaded{\def \FrameCommand {\fboxsep =\FrameSep \colorbox
{shadecolor}}\MakeFramed {\FrameRestore }\textadjustwidth}
\long\def\endshaded{\endMakeFramed}

\newcount\c@boxedtextnum
\long\def\boxedtext#1{\begin{framed}
\global\advance\c@boxedtextnum by  1
\def\one{#1}
\ifx\one\empty\else
{\boxedtextfont
\advance\hsize by -2\fboxsep
\noindent Box \thechapter.\the\c@boxedtextnum\ /\ #1}\vskip4pt\fi} 

\def\endboxedtext{\end{framed}}

%%%% <<== End shaded / Framed
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 17) Algorithms

%% for documentation -- 
%% https://mirror.las.iastate.edu/tex-archive/macros/latex/contrib/algorithmicx/algorithmicx.pdf

\usepackage{algpseudocode}
\usepackage[plain]{algorithm}

\let\listofalgorithms\relax
\newcommand{\listofalgorithms}{%
\clearpage\if@twoside 
\ifodd\c@page\else
    \hbox{}\thispagestyle{empty}\newpage\if@twocolumn\hbox{}\newpage\fi\fi\fi
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
  \columnseprule \z@
  \columnsep 35\p@
  \chapter*{List of Algorithms}
\shortaddtobrief{LIST OF ALGORITHMS}
\bookmark[page=\the\acropage, level=0]{List of Algorithms}
  \addtocontents{toc}{\relax}%
\bigsmall %% change Oct 4, 2022
 \@starttoc{loa}%
 \cleartorecto
 \noindent\ignorespaces}
{\if@restonecol\onecolumn\else\clearpage\fi}

\def\fnum@algorithm{\bf Algorithm~\thealgorithm}

\renewcommand
\thealgorithm{\ifnum\c@chapter>0\thechapter.\fi\@arabic\c@algorithm}

%%%% <<== End Algorithms %%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 18) Notation, Dialogue

\def\notation{\vskip7pt\bgroup\parskip=0pt
\def\arraystretch{1.5}
\leftskip=0pt
%\noindent{\bfseries\itshape Notation}
\chapter*{Notation}
\shortaddtobrief{NOTATION}
\bookmark[page=\the\acropage, level=0]{Notation}

\vskip6pt
\let\\=\cr
\noindent\halign\bgroup##\hfill\hskip10pt\vrule
depth 12pt width0pt height 18pt&##\hfill\\ 
\hline
}
\def\endnotation{\crcr\hline\egroup\egroup\vskip8pt}

\def\notations{\vskip7pt\bgroup\parskip=0pt
\leftskip=0pt
\def\arraystretch{1.5}
\chapter*{Notations}
\vskip6pt
\let\\=\cr
\noindent\halign\bgroup\let\mathrm\savemathrm
##\hfill\hskip10pt\vrule
depth 12pt width0pt height 18pt&##\hfill\\
\hline
}
\def\endnotations{\crcr\hline\egroup\egroup\vskip8pt}

\let\extract\quote
\let\endextract\endquote

\def\dialogue{\bgroup\vskip4pt\parindent=-18pt \leftskip=30pt}
\def\enddialogue{\vskip7pt\egroup}
\def\speaker#1{\vskip-\parskip\vskip3pt\indent{\it
#1}:\hskip10pt\relax} 

\def\dialogue{\description\item[]}
\def\speaker#1{\item[\it #1]}
\def\enddialogue{\enddescription}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 19) Exercises and Answers

\newcount\c@exernum
\newcount\c@subexernum

\def\exercises{\vskip8pt
\vskip1sp\section*{Exercises}
\global\leftskip=22pt\relax}

\def\endexercises{\vskip12pt\global\leftskip=0pt\relax}

\def\subexercises{\setcounter{subexernum}{0}
\global\leftskip=43pt}

\def\endsubexercises{\vskip1sp\global\leftskip=22pt}

\def\exer{\vskip3pt\global\advance\c@exernum by 1
\noindent\hskip-22pt\hbox to
22pt{\bf\the\c@chapter.\the\c@exernum\hfill}\def\@currentlabel{\the\c@chapter.\the\c@exernum}%
\ignorespaces}

\def\subexer{\vskip3pt\global\advance\c@subexernum by 1\relax
\noindent\hskip-22pt\hbox to
22pt{\bf(\alph{subexernum})\hfill}%
\def\@currentlabel{%\the\c@chapter.\the\c@exernum-
(\alph{subexernum})}}%

\def\answers{\vskip8pt\vskip1sp\section*{Selected Answers to Exercises}
\global\leftskip=22pt\relax}

\def\endanswers{\vskip12pt\global\leftskip=0pt\relax}

\def\answer#1{\vskip3pt
\leftskip=22pt\def\curranswer{#1}%
\noindent\hskip-22pt\hbox to
22pt{\bf\curranswer\hfill}\ignorespaces}

\def\subanswer#1{\vskip3pt
\leftskip=45pt\def\curranswer{#1}%
\noindent\hskip-22pt\hbox to
22pt{\bf\curranswer\hfill}\ignorespaces}%

%% <<== End Exercises, Answers %%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 20) Theorem Environments
\newcounter{Theorem}

\def\th@plain{%
%%  \let\thm@indent\noindent % no indent
%%  \thm@headfont{\bfseries}% heading font is bold
%%  \thm@notefont{}% same as heading font
%%  \thm@headpunct{.}% add period after heading
%%  \let\thm@swap\@gobble
%%  \thm@preskip\topsep
%%  \thm@postskip\theorempreskipamount
  \itshape % body font
%% new, Jan 23, 2023 ==>>
\leftmargini=0pt
\leftmargin=\leftmargini
}

\def\th@definition{%
  \normalfont % body font
%% new, Jan 23, 2023 ==>>
\leftmargini=0pt
\leftmargin=\leftmargini
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
{\theoremstyle{plain} % italic text for all
     %newtheorems when using this theoremstyle
\newtheorem{theorem}{Theorem}[chapter]
\newtheorem{lemma}[theorem]{Lemma}%
\newtheorem{proposition}[theorem]{Proposition}%
\newtheorem{corollary}[theorem]{Corollary}%
\newtheorem{conjecture}[theorem]{Conjecture}
}


{\theoremstyle{definition} % roman text for all 
     %newtheorems when using this theoremstyle
\newtheorem{assumption}[theorem]{Assumption}
\newtheorem{definition}[theorem]{Definition}%
\newtheorem{example}[theorem]{Example}%
\newtheorem{remark}[theorem]{Remark}
\newtheorem{exercise}[theorem]{Exercise}
}
%%%%
\def\proof{\vskip-1pt\leftskip=0pt %\leftmargini
\noindent{\it Proof.\,}}
\def\endproof{\qed\vskip1pt\leftskip=0pt\relax}


 \newdimen\slugwidth
 \newdimen\slugdepth

 \slugwidth=4.5pt
 \slugdepth=1pt



 \def\qed{\unskip\nobreak~~~\hfill\llap{%
 \vbox{\unskip\nobreak~~~\hfill\llap{\vrule height \slugwidth width 
 \slugwidth depth\slugdepth}}}}

%%% <<-- End Theorem Environments %%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 21) Hyperref 

%% according to specs:
 \paperwidth=36pc \advance\paperwidth by 9pt
 \paperheight=9in %9.25in 

 \expandafter\ifx\csname hypersetup\endcsname\relax
 \usepackage{hyperref}\fi

\hypersetup{bookmarksopen=true,
    pdfnewwindow=true,      % links in new window
   colorlinks=true,    % false: boxed links; true: colored links
  linkcolor=black,     % color of internal links
 citecolor=black,     % color of links to bibliography
     filecolor=black,     % color of file links
    urlcolor= black,     % color of external links
 breaklinks,
 hypertexnames=true % must be true for index to work
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 22) Settings for start of document

\pagestyle{PUPheadings}


%% no widow or orphan lines:
\widowpenalty=10000
\clubpenalty=10000

%% for 6x9
\parskip=0pt % plus.01pt
\textheight=538pt 
\textwidth=28pc %346pt

%Upper and lower margins: 0and 0 
\headheight =18pt
\headsep= 20.0pt %% was 30pt, changed Oct 5, 2022
\footskip= 15.0pt
\columnsep= 10pt
\columnseprule= 0pt
\marginparsep= 7pt
\marginparwidth= 54.2pt

\parindent=15pt
\footskip=24pt
\topmargin=-46pt

%% Will set all of these counters to zero with new chapter:
%\@addtoreset {boxedtextnum}{chapter}
\@addtoreset {footnote}{chapter}
\@addtoreset {equation}{chapter}
\@addtoreset {figure}{chapter}
\@addtoreset {table}{chapter}
\@addtoreset {algorithm}{chapter}
\@addtoreset{exernum}{chapter}

%% default is to start with frontmatter
\frontmatter

\newif\ifraggedbottomsection
  \raggedbottomsectionfalse
\newlength{\bottomsectionskip}
  \setlength{\bottomsectionskip}{10mm}

\pagenumbering{roman}
\pagestyle{PUPheadings}


\def\blankpage{\clearpage\thispagestyle{empty}\null\newpage}
\def\arraystretch{1.3}
\let\savethebibliography\thebibliography



  \topmargin-.75in
  \headheight 12pt
  \headsep 18pt
  \topskip  10pt
  \footskip 18pt

\newdimen\universaldrop
\universaldrop=1in
\advance\universaldrop by 24pt

\parindent=12pt

\def\@begintheorem#1#2[#3]{%
\leftskip=\leftmargini
  \deferred@thm@head{\the\thm@headfont \thm@indent
    \@ifempty{#1}{\let\thmname\@gobble}{\let\thmname\@iden}%
    \@ifempty{#2}{\let\thmnumber\@gobble}{\let\thmnumber\@iden}%
    \@ifempty{#3}{\let\thmnote\@gobble}{\let\thmnote\@iden}%
    \thm@swap\swappedhead\thmhead{#1}{#2}{#3}%
    \the\thm@headpunct
    \thmheadnl % possibly a newline.
    \hskip\thm@headsep
  }%
  \ignorespaces}

%%%%
\ifEndnote\global\let\ChapEndNotes\relax\fi
%%%%
\ifChapEndnote\global\let\BookEndNotes\relax\fi

%% default
\ifEndnote\else\ifChapEndnote\else
\global\let\BookEndNotes\relax
\global\let\ChapEndNotes\relax
\fi\fi
%%%%

%% from Cambridge U Press, for A4 paper
%\setlength\paperheight {246mm}
%\setlength\paperwidth  {189mm}

\ifsixbynine
%% To make the 6 1/8 by 9 1/4 trim size:
\paperwidth=6.125in
\advance\paperwidth by 3pt
\paperheight=9.25in
\textheight=8.25in
\advance\textheight-30pt
\advance\headheight by 8pt
\textwidth=5.125in
\advance\textwidth by 3pt
\oddsidemargin=-36pt
\evensidemargin=-36pt
\fi

\ifsevenbyten
%% To make the 7 by 10 trim size:
\paperwidth=7in
\advance\paperwidth by 3pt
\paperheight=10in
\advance \paperheight by 3pt
\textheight=9in
\advance\textheight-23pt
\advance\headheight by 8pt
\textwidth=6in
\advance\textwidth by 3pt
\oddsidemargin=-36pt
\evensidemargin=-36pt
\fi



\endinput